from enum import IntEnum


class OfflineQueryGivensVersion(IntEnum):
    """Version in which inputs to offline query is stored as a ChalkTable"""

    NATIVE_TS_FEATURE_FOR_ROOT_NS = 1
    """Replace '__chalk__.CHALK_TS' with the 'native' TS feature for the root output namespace"""

    SINGLE_TS_COL_NAME = 2
    """Replace '__chalk__.CHALK_TS' with the single column name '__ts__' (TS_COL_NAME)"""

    SINGLE_TS_COL_NAME_WITH_URI_PREFIX = 3
    """
    Replace '__chalk__.CHALK_TS' with the single column name '__ts__' (TS_COL_NAME)
    Also, this is now a prefix instead of a single file
    """


TS_COL_NAME = "__ts__"
INDEX_COL_NAME = "__index__"
PKEY_COL_NAME = "__id__"
OBSERVED_AT_COL_NAME = "__oat__"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/nodepools/v1/gke.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.rpc import code_pb2 as google_dot_rpc_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1c\x63halk/nodepools/v1/gke.proto\x12\x12\x63halk.nodepools.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x15google/rpc/code.proto"\xa0\x03\n\x0fStatusCondition\x12@\n\x04\x63ode\x18\x01 \x01(\x0e\x32(.chalk.nodepools.v1.StatusCondition.CodeB\x02\x18\x01R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x37\n\x0e\x63\x61nonical_code\x18\x03 \x01(\x0e\x32\x10.google.rpc.CodeR\rcanonicalCode"\xf7\x01\n\x04\x43ode\x12\x14\n\x10\x43ODE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x43ODE_GCE_STOCKOUT\x10\x01\x12$\n CODE_GKE_SERVICE_ACCOUNT_DELETED\x10\x02\x12\x1b\n\x17\x43ODE_GCE_QUOTA_EXCEEDED\x10\x03\x12\x18\n\x14\x43ODE_SET_BY_OPERATOR\x10\x04\x12\x1c\n\x18\x43ODE_CLOUD_KMS_KEY_ERROR\x10\x07\x12\x14\n\x10\x43ODE_CA_EXPIRING\x10\t\x12\x31\n-CODE_NODE_SERVICE_ACCOUNT_MISSING_PERMISSIONS\x10\n"\xd2\x03\n\x13NodePoolAutoscaling\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x12$\n\x0emin_node_count\x18\x02 \x01(\x05R\x0cminNodeCount\x12$\n\x0emax_node_count\x18\x03 \x01(\x05R\x0cmaxNodeCount\x12(\n\x0f\x61utoprovisioned\x18\x04 \x01(\x08R\x0f\x61utoprovisioned\x12_\n\x0flocation_policy\x18\x05 \x01(\x0e\x32\x36.chalk.nodepools.v1.NodePoolAutoscaling.LocationPolicyR\x0elocationPolicy\x12/\n\x14total_min_node_count\x18\x06 \x01(\x05R\x11totalMinNodeCount\x12/\n\x14total_max_node_count\x18\x07 \x01(\x05R\x11totalMaxNodeCount"h\n\x0eLocationPolicy\x12\x1f\n\x1bLOCATION_POLICY_UNSPECIFIED\x10\x00\x12\x1c\n\x18LOCATION_POLICY_BALANCED\x10\x01\x12\x17\n\x13LOCATION_POLICY_ANY\x10\x02"\xe1\x01\n\tNodeTaint\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\x12<\n\x06\x65\x66\x66\x65\x63t\x18\x03 \x01(\x0e\x32$.chalk.nodepools.v1.NodeTaint.EffectR\x06\x65\x66\x66\x65\x63t"n\n\x06\x45\x66\x66\x65\x63t\x12\x16\n\x12\x45\x46\x46\x45\x43T_UNSPECIFIED\x10\x00\x12\x16\n\x12\x45\x46\x46\x45\x43T_NO_SCHEDULE\x10\x01\x12\x1d\n\x19\x45\x46\x46\x45\x43T_PREFER_NO_SCHEDULE\x10\x02\x12\x15\n\x11\x45\x46\x46\x45\x43T_NO_EXECUTE\x10\x03">\n\x11MaxPodsConstraint\x12)\n\x11max_pods_per_node\x18\x01 \x01(\x03R\x0emaxPodsPerNode"b\n\x16\x42\x65stEffortProvisioning\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x12.\n\x13min_provision_nodes\x18\x02 \x01(\x05R\x11minProvisionNodes"\xa5\x01\n\x0eNodeManagement\x12!\n\x0c\x61uto_upgrade\x18\x01 \x01(\x08R\x0b\x61utoUpgrade\x12\x1f\n\x0b\x61uto_repair\x18\x02 \x01(\x08R\nautoRepair\x12O\n\x0fupgrade_options\x18\n \x01(\x0b\x32&.chalk.nodepools.v1.AutoUpgradeOptionsR\x0eupgradeOptions"m\n\x12\x41utoUpgradeOptions\x12\x35\n\x17\x61uto_upgrade_start_time\x18\x01 \x01(\tR\x14\x61utoUpgradeStartTime\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription"\xc4\x0b\n\nNodeConfig\x12!\n\x0cmachine_type\x18\x01 \x01(\tR\x0bmachineType\x12 \n\x0c\x64isk_size_gb\x18\x02 \x01(\x05R\ndiskSizeGb\x12!\n\x0coauth_scopes\x18\x03 \x03(\tR\x0boauthScopes\x12\'\n\x0fservice_account\x18\t \x01(\tR\x0eserviceAccount\x12H\n\x08metadata\x18\x04 \x03(\x0b\x32,.chalk.nodepools.v1.NodeConfig.MetadataEntryR\x08metadata\x12\x1d\n\nimage_type\x18\x05 \x01(\tR\timageType\x12\x42\n\x06labels\x18\x06 \x03(\x0b\x32*.chalk.nodepools.v1.NodeConfig.LabelsEntryR\x06labels\x12&\n\x0flocal_ssd_count\x18\x07 \x01(\x05R\rlocalSsdCount\x12\x12\n\x04tags\x18\x08 \x03(\tR\x04tags\x12 \n\x0bpreemptible\x18\n \x01(\x08R\x0bpreemptible\x12\x1b\n\tdisk_type\x18\x0c \x01(\tR\x08\x64iskType\x12(\n\x10min_cpu_platform\x18\r \x01(\tR\x0eminCpuPlatform\x12\x35\n\x06taints\x18\x0f \x03(\x0b\x32\x1d.chalk.nodepools.v1.NodeTaintR\x06taints\x12\x1d\n\nnode_group\x18\x12 \x01(\tR\tnodeGroup\x12)\n\x11\x62oot_disk_kms_key\x18\x17 \x01(\tR\x0e\x62ootDiskKmsKey\x12\x12\n\x04spot\x18  \x01(\x08R\x04spot\x12[\n\x0fresource_labels\x18% \x03(\x0b\x32\x32.chalk.nodepools.v1.NodeConfig.ResourceLabelsEntryR\x0eresourceLabels\x12u\n\x19local_ssd_encryption_mode\x18\x36 \x01(\x0e\x32\x35.chalk.nodepools.v1.NodeConfig.LocalSsdEncryptionModeH\x00R\x16localSsdEncryptionMode\x88\x01\x01\x12\x66\n\x15\x65\x66\x66\x65\x63tive_cgroup_mode\x18\x37 \x01(\x0e\x32\x32.chalk.nodepools.v1.NodeConfig.EffectiveCgroupModeR\x13\x65\x66\x66\x65\x63tiveCgroupMode\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x41\n\x13ResourceLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01"\xae\x01\n\x16LocalSsdEncryptionMode\x12)\n%LOCAL_SSD_ENCRYPTION_MODE_UNSPECIFIED\x10\x00\x12\x31\n-LOCAL_SSD_ENCRYPTION_MODE_STANDARD_ENCRYPTION\x10\x01\x12\x36\n2LOCAL_SSD_ENCRYPTION_MODE_EPHEMERAL_KEY_ENCRYPTION\x10\x02"x\n\x13\x45\x66\x66\x65\x63tiveCgroupMode\x12%\n!EFFECTIVE_CGROUP_MODE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45\x46\x46\x45\x43TIVE_CGROUP_MODE_V1\x10\x01\x12\x1c\n\x18\x45\x46\x46\x45\x43TIVE_CGROUP_MODE_V2\x10\x02\x42\x1c\n\x1a_local_ssd_encryption_mode"\xff\x03\n\x11\x42lueGreenSettings\x12u\n\x17standard_rollout_policy\x18\x01 \x01(\x0b\x32;.chalk.nodepools.v1.BlueGreenSettings.StandardRolloutPolicyH\x00R\x15standardRolloutPolicy\x12U\n\x17node_pool_soak_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationH\x01R\x14nodePoolSoakDuration\x88\x01\x01\x1a\xed\x01\n\x15StandardRolloutPolicy\x12+\n\x10\x62\x61tch_percentage\x18\x01 \x01(\x02H\x00R\x0f\x62\x61tchPercentage\x12*\n\x10\x62\x61tch_node_count\x18\x02 \x01(\x05H\x00R\x0e\x62\x61tchNodeCount\x12N\n\x13\x62\x61tch_soak_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationH\x01R\x11\x62\x61tchSoakDuration\x88\x01\x01\x42\x13\n\x11update_batch_sizeB\x16\n\x14_batch_soak_durationB\x10\n\x0erollout_policyB\x1a\n\x18_node_pool_soak_duration"\xb6\x14\n\x0bGKENodePool\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x36\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1e.chalk.nodepools.v1.NodeConfigR\x06\x63onfig\x12,\n\x12initial_node_count\x18\x03 \x01(\x05R\x10initialNodeCount\x12\x1c\n\tlocations\x18\r \x03(\tR\tlocations\x12\x1b\n\tself_link\x18\x64 \x01(\tR\x08selfLink\x12\x18\n\x07version\x18\x65 \x01(\tR\x07version\x12.\n\x13instance_group_urls\x18\x66 \x03(\tR\x11instanceGroupUrls\x12>\n\x06status\x18g \x01(\x0e\x32&.chalk.nodepools.v1.GKENodePool.StatusR\x06status\x12)\n\x0estatus_message\x18h \x01(\tB\x02\x18\x01R\rstatusMessage\x12I\n\x0b\x61utoscaling\x18\x04 \x01(\x0b\x32\'.chalk.nodepools.v1.NodePoolAutoscalingR\x0b\x61utoscaling\x12\x42\n\nmanagement\x18\x05 \x01(\x0b\x32".chalk.nodepools.v1.NodeManagementR\nmanagement\x12U\n\x13max_pods_constraint\x18\x06 \x01(\x0b\x32%.chalk.nodepools.v1.MaxPodsConstraintR\x11maxPodsConstraint\x12\x43\n\nconditions\x18i \x03(\x0b\x32#.chalk.nodepools.v1.StatusConditionR\nconditions\x12+\n\x12pod_ipv4_cidr_size\x18\x07 \x01(\x05R\x0fpodIpv4CidrSize\x12Z\n\x10upgrade_settings\x18k \x01(\x0b\x32/.chalk.nodepools.v1.GKENodePool.UpgradeSettingsR\x0fupgradeSettings\x12Z\n\x10placement_policy\x18l \x01(\x0b\x32/.chalk.nodepools.v1.GKENodePool.PlacementPolicyR\x0fplacementPolicy\x12K\n\x0bupdate_info\x18m \x01(\x0b\x32*.chalk.nodepools.v1.GKENodePool.UpdateInfoR\nupdateInfo\x12\x12\n\x04\x65tag\x18n \x01(\tR\x04\x65tag\x12\x63\n\x13queued_provisioning\x18p \x01(\x0b\x32\x32.chalk.nodepools.v1.GKENodePool.QueuedProvisioningR\x12queuedProvisioning\x12\x64\n\x18\x62\x65st_effort_provisioning\x18q \x01(\x0b\x32*.chalk.nodepools.v1.BestEffortProvisioningR\x16\x62\x65stEffortProvisioning\x1a\xa5\x02\n\x0fUpgradeSettings\x12\x1b\n\tmax_surge\x18\x01 \x01(\x05R\x08maxSurge\x12\'\n\x0fmax_unavailable\x18\x02 \x01(\x05R\x0emaxUnavailable\x12K\n\x08strategy\x18\x03 \x01(\x0e\x32*.chalk.nodepools.v1.NodePoolUpdateStrategyH\x00R\x08strategy\x88\x01\x01\x12Z\n\x13\x62lue_green_settings\x18\x04 \x01(\x0b\x32%.chalk.nodepools.v1.BlueGreenSettingsH\x01R\x11\x62lueGreenSettings\x88\x01\x01\x42\x0b\n\t_strategyB\x16\n\x14_blue_green_settings\x1a\xa8\x05\n\nUpdateInfo\x12`\n\x0f\x62lue_green_info\x18\x01 \x01(\x0b\x32\x38.chalk.nodepools.v1.GKENodePool.UpdateInfo.BlueGreenInfoR\rblueGreenInfo\x1a\xb7\x04\n\rBlueGreenInfo\x12T\n\x05phase\x18\x01 \x01(\x0e\x32>.chalk.nodepools.v1.GKENodePool.UpdateInfo.BlueGreenInfo.PhaseR\x05phase\x12\x37\n\x18\x62lue_instance_group_urls\x18\x02 \x03(\tR\x15\x62lueInstanceGroupUrls\x12\x39\n\x19green_instance_group_urls\x18\x03 \x03(\tR\x16greenInstanceGroupUrls\x12@\n\x1d\x62lue_pool_deletion_start_time\x18\x04 \x01(\tR\x19\x62luePoolDeletionStartTime\x12,\n\x12green_pool_version\x18\x05 \x01(\tR\x10greenPoolVersion"\xeb\x01\n\x05Phase\x12\x15\n\x11PHASE_UNSPECIFIED\x10\x00\x12\x18\n\x14PHASE_UPDATE_STARTED\x10\x01\x12\x1d\n\x19PHASE_CREATING_GREEN_POOL\x10\x02\x12\x1d\n\x19PHASE_CORDONING_BLUE_POOL\x10\x03\x12\x1c\n\x18PHASE_DRAINING_BLUE_POOL\x10\x04\x12\x1b\n\x17PHASE_NODE_POOL_SOAKING\x10\x05\x12\x1c\n\x18PHASE_DELETING_BLUE_POOL\x10\x06\x12\x1a\n\x16PHASE_ROLLBACK_STARTED\x10\x07\x1a\xcf\x01\n\x0fPlacementPolicy\x12H\n\x04type\x18\x01 \x01(\x0e\x32\x34.chalk.nodepools.v1.GKENodePool.PlacementPolicy.TypeR\x04type\x12!\n\x0ctpu_topology\x18\x02 \x01(\tR\x0btpuTopology\x12\x1f\n\x0bpolicy_name\x18\x03 \x01(\tR\npolicyName".\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cTYPE_COMPACT\x10\x01\x1a.\n\x12QueuedProvisioning\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled"\xab\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13STATUS_PROVISIONING\x10\x01\x12\x12\n\x0eSTATUS_RUNNING\x10\x02\x12\x1d\n\x19STATUS_RUNNING_WITH_ERROR\x10\x03\x12\x16\n\x12STATUS_RECONCILING\x10\x04\x12\x13\n\x0fSTATUS_STOPPING\x10\x05\x12\x10\n\x0cSTATUS_ERROR\x10\x06*\x92\x01\n\x16NodePoolUpdateStrategy\x12)\n%NODE_POOL_UPDATE_STRATEGY_UNSPECIFIED\x10\x00\x12(\n$NODE_POOL_UPDATE_STRATEGY_BLUE_GREEN\x10\x02\x12#\n\x1fNODE_POOL_UPDATE_STRATEGY_SURGE\x10\x03\x42\xa6\x01\n\x16\x63om.chalk.nodepools.v1B\x08GkeProtoP\x01Z\x18nodepools/v1;nodepoolsv1\xa2\x02\x03\x43NX\xaa\x02\x12\x43halk.Nodepools.V1\xca\x02\x12\x43halk\\Nodepools\\V1\xe2\x02\x1e\x43halk\\Nodepools\\V1\\GPBMetadata\xea\x02\x14\x43halk::Nodepools::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.nodepools.v1.gke_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\026com.chalk.nodepools.v1B\010GkeProtoP\001Z\030nodepools/v1;nodepoolsv1\242\002\003CNX\252\002\022Chalk.Nodepools.V1\312\002\022Chalk\\Nodepools\\V1\342\002\036Chalk\\Nodepools\\V1\\GPBMetadata\352\002\024Chalk::Nodepools::V1"
    _globals["_STATUSCONDITION"].fields_by_name["code"]._options = None
    _globals["_STATUSCONDITION"].fields_by_name["code"]._serialized_options = b"\030\001"
    _globals["_NODECONFIG_METADATAENTRY"]._options = None
    _globals["_NODECONFIG_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_NODECONFIG_LABELSENTRY"]._options = None
    _globals["_NODECONFIG_LABELSENTRY"]._serialized_options = b"8\001"
    _globals["_NODECONFIG_RESOURCELABELSENTRY"]._options = None
    _globals["_NODECONFIG_RESOURCELABELSENTRY"]._serialized_options = b"8\001"
    _globals["_GKENODEPOOL"].fields_by_name["status_message"]._options = None
    _globals["_GKENODEPOOL"].fields_by_name["status_message"]._serialized_options = b"\030\001"
    _globals["_NODEPOOLUPDATESTRATEGY"]._serialized_start = 6277
    _globals["_NODEPOOLUPDATESTRATEGY"]._serialized_end = 6423
    _globals["_STATUSCONDITION"]._serialized_start = 108
    _globals["_STATUSCONDITION"]._serialized_end = 524
    _globals["_STATUSCONDITION_CODE"]._serialized_start = 277
    _globals["_STATUSCONDITION_CODE"]._serialized_end = 524
    _globals["_NODEPOOLAUTOSCALING"]._serialized_start = 527
    _globals["_NODEPOOLAUTOSCALING"]._serialized_end = 993
    _globals["_NODEPOOLAUTOSCALING_LOCATIONPOLICY"]._serialized_start = 889
    _globals["_NODEPOOLAUTOSCALING_LOCATIONPOLICY"]._serialized_end = 993
    _globals["_NODETAINT"]._serialized_start = 996
    _globals["_NODETAINT"]._serialized_end = 1221
    _globals["_NODETAINT_EFFECT"]._serialized_start = 1111
    _globals["_NODETAINT_EFFECT"]._serialized_end = 1221
    _globals["_MAXPODSCONSTRAINT"]._serialized_start = 1223
    _globals["_MAXPODSCONSTRAINT"]._serialized_end = 1285
    _globals["_BESTEFFORTPROVISIONING"]._serialized_start = 1287
    _globals["_BESTEFFORTPROVISIONING"]._serialized_end = 1385
    _globals["_NODEMANAGEMENT"]._serialized_start = 1388
    _globals["_NODEMANAGEMENT"]._serialized_end = 1553
    _globals["_AUTOUPGRADEOPTIONS"]._serialized_start = 1555
    _globals["_AUTOUPGRADEOPTIONS"]._serialized_end = 1664
    _globals["_NODECONFIG"]._serialized_start = 1667
    _globals["_NODECONFIG"]._serialized_end = 3143
    _globals["_NODECONFIG_METADATAENTRY"]._serialized_start = 2629
    _globals["_NODECONFIG_METADATAENTRY"]._serialized_end = 2688
    _globals["_NODECONFIG_LABELSENTRY"]._serialized_start = 2690
    _globals["_NODECONFIG_LABELSENTRY"]._serialized_end = 2747
    _globals["_NODECONFIG_RESOURCELABELSENTRY"]._serialized_start = 2749
    _globals["_NODECONFIG_RESOURCELABELSENTRY"]._serialized_end = 2814
    _globals["_NODECONFIG_LOCALSSDENCRYPTIONMODE"]._serialized_start = 2817
    _globals["_NODECONFIG_LOCALSSDENCRYPTIONMODE"]._serialized_end = 2991
    _globals["_NODECONFIG_EFFECTIVECGROUPMODE"]._serialized_start = 2993
    _globals["_NODECONFIG_EFFECTIVECGROUPMODE"]._serialized_end = 3113
    _globals["_BLUEGREENSETTINGS"]._serialized_start = 3146
    _globals["_BLUEGREENSETTINGS"]._serialized_end = 3657
    _globals["_BLUEGREENSETTINGS_STANDARDROLLOUTPOLICY"]._serialized_start = 3374
    _globals["_BLUEGREENSETTINGS_STANDARDROLLOUTPOLICY"]._serialized_end = 3611
    _globals["_GKENODEPOOL"]._serialized_start = 3660
    _globals["_GKENODEPOOL"]._serialized_end = 6274
    _globals["_GKENODEPOOL_UPGRADESETTINGS"]._serialized_start = 4866
    _globals["_GKENODEPOOL_UPGRADESETTINGS"]._serialized_end = 5159
    _globals["_GKENODEPOOL_UPDATEINFO"]._serialized_start = 5162
    _globals["_GKENODEPOOL_UPDATEINFO"]._serialized_end = 5842
    _globals["_GKENODEPOOL_UPDATEINFO_BLUEGREENINFO"]._serialized_start = 5275
    _globals["_GKENODEPOOL_UPDATEINFO_BLUEGREENINFO"]._serialized_end = 5842
    _globals["_GKENODEPOOL_UPDATEINFO_BLUEGREENINFO_PHASE"]._serialized_start = 5607
    _globals["_GKENODEPOOL_UPDATEINFO_BLUEGREENINFO_PHASE"]._serialized_end = 5842
    _globals["_GKENODEPOOL_PLACEMENTPOLICY"]._serialized_start = 5845
    _globals["_GKENODEPOOL_PLACEMENTPOLICY"]._serialized_end = 6052
    _globals["_GKENODEPOOL_PLACEMENTPOLICY_TYPE"]._serialized_start = 6006
    _globals["_GKENODEPOOL_PLACEMENTPOLICY_TYPE"]._serialized_end = 6052
    _globals["_GKENODEPOOL_QUEUEDPROVISIONING"]._serialized_start = 6054
    _globals["_GKENODEPOOL_QUEUEDPROVISIONING"]._serialized_end = 6100
    _globals["_GKENODEPOOL_STATUS"]._serialized_start = 6103
    _globals["_GKENODEPOOL_STATUS"]._serialized_end = 6274
# @@protoc_insertion_point(module_scope)



from chalk._gen.chalk.auth.v1 import agent_pb2 as _agent_pb2
from chalk._gen.chalk.auth.v1 import permissions_pb2 as _permissions_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.rpc import code_pb2 as _code_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class AuditLog(_message.Message):
    __slots__ = ("agent", "description", "endpoint", "at", "trace_id", "code", "request", "response", "ip", "error")
    class RequestEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...
        ) -> None: ...

    class ResponseEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _struct_pb2.Value
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[_Union[_struct_pb2.Value, _Mapping]] = ...
        ) -> None: ...

    AGENT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    AT_FIELD_NUMBER: _ClassVar[int]
    TRACE_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    IP_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    agent: _agent_pb2.Agent
    description: str
    endpoint: str
    at: _timestamp_pb2.Timestamp
    trace_id: int
    code: _code_pb2.Code
    request: _containers.MessageMap[str, _struct_pb2.Value]
    response: _containers.MessageMap[str, _struct_pb2.Value]
    ip: str
    error: str
    def __init__(
        self,
        agent: _Optional[_Union[_agent_pb2.Agent, _Mapping]] = ...,
        description: _Optional[str] = ...,
        endpoint: _Optional[str] = ...,
        at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        trace_id: _Optional[int] = ...,
        code: _Optional[_Union[_code_pb2.Code, str]] = ...,
        request: _Optional[_Mapping[str, _struct_pb2.Value]] = ...,
        response: _Optional[_Mapping[str, _struct_pb2.Value]] = ...,
        ip: _Optional[str] = ...,
        error: _Optional[str] = ...,
    ) -> None: ...

class GetAuditLogsRequest(_message.Message):
    __slots__ = ("start_time", "end_time", "endpoint_filter")
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FILTER_FIELD_NUMBER: _ClassVar[int]
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    endpoint_filter: _containers.RepeatedScalarFieldContainer[str]
    def __init__(
        self,
        start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        endpoint_filter: _Optional[_Iterable[str]] = ...,
    ) -> None: ...

class GetAuditLogsResponse(_message.Message):
    __slots__ = ("logs",)
    LOGS_FIELD_NUMBER: _ClassVar[int]
    logs: _containers.RepeatedCompositeFieldContainer[AuditLog]
    def __init__(self, logs: _Optional[_Iterable[_Union[AuditLog, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class MetricKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    METRIC_KIND_UNSPECIFIED: _ClassVar[MetricKind]
    METRIC_KIND_FEATURE_REQUEST_COUNT: _ClassVar[MetricKind]
    METRIC_KIND_FEATURE_LATENCY: _ClassVar[MetricKind]
    METRIC_KIND_FEATURE_STALENESS: _ClassVar[MetricKind]
    METRIC_KIND_FEATURE_VALUE: _ClassVar[MetricKind]
    METRIC_KIND_FEATURE_WRITE: _ClassVar[MetricKind]
    METRIC_KIND_FEATURE_NULL_RATIO: _ClassVar[MetricKind]
    METRIC_KIND_RESOLVER_REQUEST_COUNT: _ClassVar[MetricKind]
    METRIC_KIND_RESOLVER_LATENCY: _ClassVar[MetricKind]
    METRIC_KIND_RESOLVER_SUCCESS_RATIO: _ClassVar[MetricKind]
    METRIC_KIND_QUERY_COUNT: _ClassVar[MetricKind]
    METRIC_KIND_QUERY_LATENCY: _ClassVar[MetricKind]
    METRIC_KIND_QUERY_SUCCESS_RATIO: _ClassVar[MetricKind]
    METRIC_KIND_BILLING_INFERENCE: _ClassVar[MetricKind]
    METRIC_KIND_BILLING_CRON: _ClassVar[MetricKind]
    METRIC_KIND_BILLING_MIGRATION: _ClassVar[MetricKind]
    METRIC_KIND_CRON_COUNT: _ClassVar[MetricKind]
    METRIC_KIND_CRON_LATENCY: _ClassVar[MetricKind]
    METRIC_KIND_STREAM_MESSAGES_PROCESSED: _ClassVar[MetricKind]
    METRIC_KIND_STREAM_MESSAGE_LATENCY: _ClassVar[MetricKind]
    METRIC_KIND_STREAM_WINDOWS_PROCESSED: _ClassVar[MetricKind]
    METRIC_KIND_STREAM_WINDOW_LATENCY: _ClassVar[MetricKind]
    METRIC_KIND_ONLINE_STORE_KEY_COUNT: _ClassVar[MetricKind]
    METRIC_KIND_ONLINE_STORE_EXPIRED_KEY_COUNT: _ClassVar[MetricKind]
    METRIC_KIND_ONLINE_STORE_REQUESTS_PER_SECOND: _ClassVar[MetricKind]
    METRIC_KIND_CPU_UTILIZATION_PERCENT: _ClassVar[MetricKind]
    METRIC_KIND_REPLICA_COUNT: _ClassVar[MetricKind]
    METRIC_KIND_ONLINE_STORE_USED_MEMORY: _ClassVar[MetricKind]
    METRIC_KIND_ONLINE_STORE_TOTAL_MEMORY: _ClassVar[MetricKind]
    METRIC_KIND_MEMORY_USAGE_BYTES: _ClassVar[MetricKind]
    METRIC_KIND_TOTAL_MEMORY_AVAILABLE_BYTES: _ClassVar[MetricKind]
    METRIC_KIND_NETWORK_READ_BYTES: _ClassVar[MetricKind]
    METRIC_KIND_NETWORK_WRITE_BYTES: _ClassVar[MetricKind]
    METRIC_KIND_DISK_READ_BYTES: _ClassVar[MetricKind]
    METRIC_KIND_DISK_WRITE_BYTES: _ClassVar[MetricKind]
    METRIC_KIND_STREAM_LAG: _ClassVar[MetricKind]
    METRIC_KIND_USAGE: _ClassVar[MetricKind]

class FilterKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    FILTER_KIND_UNSPECIFIED: _ClassVar[FilterKind]
    FILTER_KIND_FEATURE_STATUS: _ClassVar[FilterKind]
    FILTER_KIND_FEATURE_NAME: _ClassVar[FilterKind]
    FILTER_KIND_FEATURE_TAG: _ClassVar[FilterKind]
    FILTER_KIND_RESOLVER_STATUS: _ClassVar[FilterKind]
    FILTER_KIND_RESOLVER_NAME: _ClassVar[FilterKind]
    FILTER_KIND_RESOLVER_TAG: _ClassVar[FilterKind]
    FILTER_KIND_CRON_STATUS: _ClassVar[FilterKind]
    FILTER_KIND_MIGRATION_STATUS: _ClassVar[FilterKind]
    FILTER_KIND_ONLINE_OFFLINE: _ClassVar[FilterKind]
    FILTER_KIND_CACHE_HIT: _ClassVar[FilterKind]
    FILTER_KIND_OPERATION_ID: _ClassVar[FilterKind]
    FILTER_KIND_QUERY_NAME: _ClassVar[FilterKind]
    FILTER_KIND_QUERY_STATUS: _ClassVar[FilterKind]
    FILTER_KIND_IS_NULL: _ClassVar[FilterKind]
    FILTER_KIND_USAGE_KIND: _ClassVar[FilterKind]
    FILTER_KIND_RESOURCE_GROUP: _ClassVar[FilterKind]
    FILTER_KIND_POD_NAME: _ClassVar[FilterKind]

class ComparatorKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    COMPARATOR_KIND_UNSPECIFIED: _ClassVar[ComparatorKind]
    COMPARATOR_KIND_EQ: _ClassVar[ComparatorKind]
    COMPARATOR_KIND_NEQ: _ClassVar[ComparatorKind]
    COMPARATOR_KIND_ONE_OF: _ClassVar[ComparatorKind]

class WindowFunctionKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WINDOW_FUNCTION_KIND_UNSPECIFIED: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_COUNT: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_MEAN: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_SUM: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_MIN: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_MAX: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_PERCENTILE_99: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_PERCENTILE_95: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_PERCENTILE_75: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_PERCENTILE_50: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_PERCENTILE_25: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_PERCENTILE_5: _ClassVar[WindowFunctionKind]
    WINDOW_FUNCTION_KIND_ALL_PERCENTILES: _ClassVar[WindowFunctionKind]

class GroupByKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    GROUP_BY_KIND_UNSPECIFIED: _ClassVar[GroupByKind]
    GROUP_BY_KIND_FEATURE_STATUS: _ClassVar[GroupByKind]
    GROUP_BY_KIND_FEATURE_NAME: _ClassVar[GroupByKind]
    GROUP_BY_KIND_IS_NULL: _ClassVar[GroupByKind]
    GROUP_BY_KIND_RESOLVER_STATUS: _ClassVar[GroupByKind]
    GROUP_BY_KIND_RESOLVER_NAME: _ClassVar[GroupByKind]
    GROUP_BY_KIND_QUERY_STATUS: _ClassVar[GroupByKind]
    GROUP_BY_KIND_QUERY_NAME: _ClassVar[GroupByKind]
    GROUP_BY_KIND_ONLINE_OFFLINE: _ClassVar[GroupByKind]
    GROUP_BY_KIND_CACHE_HIT: _ClassVar[GroupByKind]
    GROUP_BY_KIND_USAGE_KIND: _ClassVar[GroupByKind]
    GROUP_BY_KIND_RESOURCE_GROUP: _ClassVar[GroupByKind]
    GROUP_BY_KIND_DEPLOYMENT_ID: _ClassVar[GroupByKind]
    GROUP_BY_KIND_OPERATION_ID: _ClassVar[GroupByKind]
    GROUP_BY_KIND_POD_NAME: _ClassVar[GroupByKind]

class MetricFormulaKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    METRIC_FORMULA_KIND_UNSPECIFIED: _ClassVar[MetricFormulaKind]
    METRIC_FORMULA_KIND_SUM: _ClassVar[MetricFormulaKind]
    METRIC_FORMULA_KIND_TOTAL_RATIO: _ClassVar[MetricFormulaKind]
    METRIC_FORMULA_KIND_RATIO: _ClassVar[MetricFormulaKind]
    METRIC_FORMULA_KIND_PRODUCT: _ClassVar[MetricFormulaKind]
    METRIC_FORMULA_KIND_ABS: _ClassVar[MetricFormulaKind]
    METRIC_FORMULA_KIND_KS_STAT: _ClassVar[MetricFormulaKind]
    METRIC_FORMULA_KIND_KS_TEST: _ClassVar[MetricFormulaKind]
    METRIC_FORMULA_KIND_KS_THRESHOLD: _ClassVar[MetricFormulaKind]
    METRIC_FORMULA_KIND_TIME_OFFSET: _ClassVar[MetricFormulaKind]

class AlertSeverityKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ALERT_SEVERITY_KIND_UNSPECIFIED: _ClassVar[AlertSeverityKind]
    ALERT_SEVERITY_KIND_CRITICAL: _ClassVar[AlertSeverityKind]
    ALERT_SEVERITY_KIND_ERROR: _ClassVar[AlertSeverityKind]
    ALERT_SEVERITY_KIND_WARNING: _ClassVar[AlertSeverityKind]
    ALERT_SEVERITY_KIND_INFO: _ClassVar[AlertSeverityKind]

class ThresholdKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    THRESHOLD_KIND_UNSPECIFIED: _ClassVar[ThresholdKind]
    THRESHOLD_KIND_ABOVE: _ClassVar[ThresholdKind]
    THRESHOLD_KIND_BELOW: _ClassVar[ThresholdKind]
    THRESHOLD_KIND_GREATER_EQUAL: _ClassVar[ThresholdKind]
    THRESHOLD_KIND_LESS_EQUAL: _ClassVar[ThresholdKind]
    THRESHOLD_KIND_EQUAL: _ClassVar[ThresholdKind]
    THRESHOLD_KIND_NOT_EQUAL: _ClassVar[ThresholdKind]

class ChartLinkKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CHART_LINK_KIND_UNSPECIFIED: _ClassVar[ChartLinkKind]
    CHART_LINK_KIND_RESOLVER: _ClassVar[ChartLinkKind]
    CHART_LINK_KIND_FEATURE: _ClassVar[ChartLinkKind]
    CHART_LINK_KIND_QUERY: _ClassVar[ChartLinkKind]
    CHART_LINK_KIND_MANUAL: _ClassVar[ChartLinkKind]
    CHART_LINK_KIND_SCHEDULED_QUERY: _ClassVar[ChartLinkKind]

METRIC_KIND_UNSPECIFIED: MetricKind
METRIC_KIND_FEATURE_REQUEST_COUNT: MetricKind
METRIC_KIND_FEATURE_LATENCY: MetricKind
METRIC_KIND_FEATURE_STALENESS: MetricKind
METRIC_KIND_FEATURE_VALUE: MetricKind
METRIC_KIND_FEATURE_WRITE: MetricKind
METRIC_KIND_FEATURE_NULL_RATIO: MetricKind
METRIC_KIND_RESOLVER_REQUEST_COUNT: MetricKind
METRIC_KIND_RESOLVER_LATENCY: MetricKind
METRIC_KIND_RESOLVER_SUCCESS_RATIO: MetricKind
METRIC_KIND_QUERY_COUNT: MetricKind
METRIC_KIND_QUERY_LATENCY: MetricKind
METRIC_KIND_QUERY_SUCCESS_RATIO: MetricKind
METRIC_KIND_BILLING_INFERENCE: MetricKind
METRIC_KIND_BILLING_CRON: MetricKind
METRIC_KIND_BILLING_MIGRATION: MetricKind
METRIC_KIND_CRON_COUNT: MetricKind
METRIC_KIND_CRON_LATENCY: MetricKind
METRIC_KIND_STREAM_MESSAGES_PROCESSED: MetricKind
METRIC_KIND_STREAM_MESSAGE_LATENCY: MetricKind
METRIC_KIND_STREAM_WINDOWS_PROCESSED: MetricKind
METRIC_KIND_STREAM_WINDOW_LATENCY: MetricKind
METRIC_KIND_ONLINE_STORE_KEY_COUNT: MetricKind
METRIC_KIND_ONLINE_STORE_EXPIRED_KEY_COUNT: MetricKind
METRIC_KIND_ONLINE_STORE_REQUESTS_PER_SECOND: MetricKind
METRIC_KIND_CPU_UTILIZATION_PERCENT: MetricKind
METRIC_KIND_REPLICA_COUNT: MetricKind
METRIC_KIND_ONLINE_STORE_USED_MEMORY: MetricKind
METRIC_KIND_ONLINE_STORE_TOTAL_MEMORY: MetricKind
METRIC_KIND_MEMORY_USAGE_BYTES: MetricKind
METRIC_KIND_TOTAL_MEMORY_AVAILABLE_BYTES: MetricKind
METRIC_KIND_NETWORK_READ_BYTES: MetricKind
METRIC_KIND_NETWORK_WRITE_BYTES: MetricKind
METRIC_KIND_DISK_READ_BYTES: MetricKind
METRIC_KIND_DISK_WRITE_BYTES: MetricKind
METRIC_KIND_STREAM_LAG: MetricKind
METRIC_KIND_USAGE: MetricKind
FILTER_KIND_UNSPECIFIED: FilterKind
FILTER_KIND_FEATURE_STATUS: FilterKind
FILTER_KIND_FEATURE_NAME: FilterKind
FILTER_KIND_FEATURE_TAG: FilterKind
FILTER_KIND_RESOLVER_STATUS: FilterKind
FILTER_KIND_RESOLVER_NAME: FilterKind
FILTER_KIND_RESOLVER_TAG: FilterKind
FILTER_KIND_CRON_STATUS: FilterKind
FILTER_KIND_MIGRATION_STATUS: FilterKind
FILTER_KIND_ONLINE_OFFLINE: FilterKind
FILTER_KIND_CACHE_HIT: FilterKind
FILTER_KIND_OPERATION_ID: FilterKind
FILTER_KIND_QUERY_NAME: FilterKind
FILTER_KIND_QUERY_STATUS: FilterKind
FILTER_KIND_IS_NULL: FilterKind
FILTER_KIND_USAGE_KIND: FilterKind
FILTER_KIND_RESOURCE_GROUP: FilterKind
FILTER_KIND_POD_NAME: FilterKind
COMPARATOR_KIND_UNSPECIFIED: ComparatorKind
COMPARATOR_KIND_EQ: ComparatorKind
COMPARATOR_KIND_NEQ: ComparatorKind
COMPARATOR_KIND_ONE_OF: ComparatorKind
WINDOW_FUNCTION_KIND_UNSPECIFIED: WindowFunctionKind
WINDOW_FUNCTION_KIND_COUNT: WindowFunctionKind
WINDOW_FUNCTION_KIND_MEAN: WindowFunctionKind
WINDOW_FUNCTION_KIND_SUM: WindowFunctionKind
WINDOW_FUNCTION_KIND_MIN: WindowFunctionKind
WINDOW_FUNCTION_KIND_MAX: WindowFunctionKind
WINDOW_FUNCTION_KIND_PERCENTILE_99: WindowFunctionKind
WINDOW_FUNCTION_KIND_PERCENTILE_95: WindowFunctionKind
WINDOW_FUNCTION_KIND_PERCENTILE_75: WindowFunctionKind
WINDOW_FUNCTION_KIND_PERCENTILE_50: WindowFunctionKind
WINDOW_FUNCTION_KIND_PERCENTILE_25: WindowFunctionKind
WINDOW_FUNCTION_KIND_PERCENTILE_5: WindowFunctionKind
WINDOW_FUNCTION_KIND_ALL_PERCENTILES: WindowFunctionKind
GROUP_BY_KIND_UNSPECIFIED: GroupByKind
GROUP_BY_KIND_FEATURE_STATUS: GroupByKind
GROUP_BY_KIND_FEATURE_NAME: GroupByKind
GROUP_BY_KIND_IS_NULL: GroupByKind
GROUP_BY_KIND_RESOLVER_STATUS: GroupByKind
GROUP_BY_KIND_RESOLVER_NAME: GroupByKind
GROUP_BY_KIND_QUERY_STATUS: GroupByKind
GROUP_BY_KIND_QUERY_NAME: GroupByKind
GROUP_BY_KIND_ONLINE_OFFLINE: GroupByKind
GROUP_BY_KIND_CACHE_HIT: GroupByKind
GROUP_BY_KIND_USAGE_KIND: GroupByKind
GROUP_BY_KIND_RESOURCE_GROUP: GroupByKind
GROUP_BY_KIND_DEPLOYMENT_ID: GroupByKind
GROUP_BY_KIND_OPERATION_ID: GroupByKind
GROUP_BY_KIND_POD_NAME: GroupByKind
METRIC_FORMULA_KIND_UNSPECIFIED: MetricFormulaKind
METRIC_FORMULA_KIND_SUM: MetricFormulaKind
METRIC_FORMULA_KIND_TOTAL_RATIO: MetricFormulaKind
METRIC_FORMULA_KIND_RATIO: MetricFormulaKind
METRIC_FORMULA_KIND_PRODUCT: MetricFormulaKind
METRIC_FORMULA_KIND_ABS: MetricFormulaKind
METRIC_FORMULA_KIND_KS_STAT: MetricFormulaKind
METRIC_FORMULA_KIND_KS_TEST: MetricFormulaKind
METRIC_FORMULA_KIND_KS_THRESHOLD: MetricFormulaKind
METRIC_FORMULA_KIND_TIME_OFFSET: MetricFormulaKind
ALERT_SEVERITY_KIND_UNSPECIFIED: AlertSeverityKind
ALERT_SEVERITY_KIND_CRITICAL: AlertSeverityKind
ALERT_SEVERITY_KIND_ERROR: AlertSeverityKind
ALERT_SEVERITY_KIND_WARNING: AlertSeverityKind
ALERT_SEVERITY_KIND_INFO: AlertSeverityKind
THRESHOLD_KIND_UNSPECIFIED: ThresholdKind
THRESHOLD_KIND_ABOVE: ThresholdKind
THRESHOLD_KIND_BELOW: ThresholdKind
THRESHOLD_KIND_GREATER_EQUAL: ThresholdKind
THRESHOLD_KIND_LESS_EQUAL: ThresholdKind
THRESHOLD_KIND_EQUAL: ThresholdKind
THRESHOLD_KIND_NOT_EQUAL: ThresholdKind
CHART_LINK_KIND_UNSPECIFIED: ChartLinkKind
CHART_LINK_KIND_RESOLVER: ChartLinkKind
CHART_LINK_KIND_FEATURE: ChartLinkKind
CHART_LINK_KIND_QUERY: ChartLinkKind
CHART_LINK_KIND_MANUAL: ChartLinkKind
CHART_LINK_KIND_SCHEDULED_QUERY: ChartLinkKind

class AlertTrigger(_message.Message):
    __slots__ = (
        "name",
        "severity",
        "threshold_position",
        "threshold_value",
        "series_name",
        "channel_name",
        "description",
    )
    NAME_FIELD_NUMBER: _ClassVar[int]
    SEVERITY_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_POSITION_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_VALUE_FIELD_NUMBER: _ClassVar[int]
    SERIES_NAME_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    severity: AlertSeverityKind
    threshold_position: ThresholdKind
    threshold_value: float
    series_name: str
    channel_name: str
    description: str
    def __init__(
        self,
        name: _Optional[str] = ...,
        severity: _Optional[_Union[AlertSeverityKind, str]] = ...,
        threshold_position: _Optional[_Union[ThresholdKind, str]] = ...,
        threshold_value: _Optional[float] = ...,
        series_name: _Optional[str] = ...,
        channel_name: _Optional[str] = ...,
        description: _Optional[str] = ...,
    ) -> None: ...

class DatasetFeatureOperand(_message.Message):
    __slots__ = ("dataset", "feature")
    DATASET_FIELD_NUMBER: _ClassVar[int]
    FEATURE_FIELD_NUMBER: _ClassVar[int]
    dataset: str
    feature: str
    def __init__(self, dataset: _Optional[str] = ..., feature: _Optional[str] = ...) -> None: ...

class MetricFormula(_message.Message):
    __slots__ = ("kind", "single_series_operands", "multi_series_operands", "dataset_feature_operands", "name")
    KIND_FIELD_NUMBER: _ClassVar[int]
    SINGLE_SERIES_OPERANDS_FIELD_NUMBER: _ClassVar[int]
    MULTI_SERIES_OPERANDS_FIELD_NUMBER: _ClassVar[int]
    DATASET_FEATURE_OPERANDS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    kind: MetricFormulaKind
    single_series_operands: int
    multi_series_operands: _containers.RepeatedScalarFieldContainer[int]
    dataset_feature_operands: DatasetFeatureOperand
    name: str
    def __init__(
        self,
        kind: _Optional[_Union[MetricFormulaKind, str]] = ...,
        single_series_operands: _Optional[int] = ...,
        multi_series_operands: _Optional[_Iterable[int]] = ...,
        dataset_feature_operands: _Optional[_Union[DatasetFeatureOperand, _Mapping]] = ...,
        name: _Optional[str] = ...,
    ) -> None: ...

class MetricFilter(_message.Message):
    __slots__ = ("kind", "comparator", "value")
    KIND_FIELD_NUMBER: _ClassVar[int]
    COMPARATOR_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    kind: FilterKind
    comparator: ComparatorKind
    value: _containers.RepeatedScalarFieldContainer[str]
    def __init__(
        self,
        kind: _Optional[_Union[FilterKind, str]] = ...,
        comparator: _Optional[_Union[ComparatorKind, str]] = ...,
        value: _Optional[_Iterable[str]] = ...,
    ) -> None: ...

class MetricConfigSeries(_message.Message):
    __slots__ = ("metric", "filters", "name", "window_function", "group_by")
    METRIC_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    WINDOW_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    metric: MetricKind
    filters: _containers.RepeatedCompositeFieldContainer[MetricFilter]
    name: str
    window_function: WindowFunctionKind
    group_by: _containers.RepeatedScalarFieldContainer[GroupByKind]
    def __init__(
        self,
        metric: _Optional[_Union[MetricKind, str]] = ...,
        filters: _Optional[_Iterable[_Union[MetricFilter, _Mapping]]] = ...,
        name: _Optional[str] = ...,
        window_function: _Optional[_Union[WindowFunctionKind, str]] = ...,
        group_by: _Optional[_Iterable[_Union[GroupByKind, str]]] = ...,
    ) -> None: ...

class MetricConfig(_message.Message):
    __slots__ = ("name", "window_period", "series", "formulas", "trigger", "graph_generated")
    NAME_FIELD_NUMBER: _ClassVar[int]
    WINDOW_PERIOD_FIELD_NUMBER: _ClassVar[int]
    SERIES_FIELD_NUMBER: _ClassVar[int]
    FORMULAS_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_FIELD_NUMBER: _ClassVar[int]
    GRAPH_GENERATED_FIELD_NUMBER: _ClassVar[int]
    name: str
    window_period: str
    series: _containers.RepeatedCompositeFieldContainer[MetricConfigSeries]
    formulas: _containers.RepeatedCompositeFieldContainer[MetricFormula]
    trigger: AlertTrigger
    graph_generated: bool
    def __init__(
        self,
        name: _Optional[str] = ...,
        window_period: _Optional[str] = ...,
        series: _Optional[_Iterable[_Union[MetricConfigSeries, _Mapping]]] = ...,
        formulas: _Optional[_Iterable[_Union[MetricFormula, _Mapping]]] = ...,
        trigger: _Optional[_Union[AlertTrigger, _Mapping]] = ...,
        graph_generated: bool = ...,
    ) -> None: ...

class Chart(_message.Message):
    __slots__ = ("id", "config", "entity_kind", "entity_id", "graph_generated")
    ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    ENTITY_KIND_FIELD_NUMBER: _ClassVar[int]
    ENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    GRAPH_GENERATED_FIELD_NUMBER: _ClassVar[int]
    id: str
    config: MetricConfig
    entity_kind: ChartLinkKind
    entity_id: str
    graph_generated: bool
    def __init__(
        self,
        id: _Optional[str] = ...,
        config: _Optional[_Union[MetricConfig, _Mapping]] = ...,
        entity_kind: _Optional[_Union[ChartLinkKind, str]] = ...,
        entity_id: _Optional[str] = ...,
        graph_generated: bool = ...,
    ) -> None: ...



from __future__ import annotations

import os
from typing import TYPE_CHECKING, Any, Dict, Mapping, Optional

from chalk.integrations.named import create_integration_variable, load_integration_variable
from chalk.sql._internal.sql_source import BaseSQLSource, SQLSourceKind
from chalk.utils.missing_dependency import missing_dependency_exception

if TYPE_CHECKING:
    from sqlalchemy.engine.url import URL


_CLOUDSQL_INSTANCE_NAME_NAME = "CLOUDSQL_INSTANCE_NAME"
_CLOUDSQL_DATABASE_NAME = "CLOUDSQL_DATABASE"
_CLOUDSQL_USER_NAME = "CLOUDSQL_USER"
_CLOUDSQL_PASSWORD_NAME = "CLOUDSQL_PASSWORD"


class CloudSQLSourceImpl(BaseSQLSource):
    kind = SQLSourceKind.cloudsql

    def __init__(
        self,
        *,
        instance_name: Optional[str] = None,
        db: Optional[str] = None,
        user: Optional[str] = None,
        password: Optional[str] = None,
        name: Optional[str] = None,
        engine_args: Optional[Dict[str, Any]] = None,
        async_engine_args: Optional[Dict[str, Any]] = None,
        integration_variable_override: Optional[Mapping[str, str]] = None,
    ):
        try:
            import psycopg
            import psycopg2
            from sqlalchemy.dialects import registry  # pyright: ignore
        except ImportError:
            raise missing_dependency_exception("chalkpy[postgresql]")
        del psycopg2  # unused
        del psycopg
        if "postgresql.psycopg" not in registry.impls:
            registry.register(
                "postgresql.psycopg", "chalk.sql._internal.integrations.psycopg3.psycopg_dialect", "dialect"
            )
        if "postgresql.psycopg_async" not in registry.impls:
            registry.register(
                "postgresql.psycopg_async", "chalk.sql._internal.integrations.psycopg3.psycopg_dialect", "dialect_async"
            )
        self.instance_name = instance_name or load_integration_variable(
            name=_CLOUDSQL_INSTANCE_NAME_NAME, integration_name=name, override=integration_variable_override
        )
        self.db = db or load_integration_variable(
            name=_CLOUDSQL_DATABASE_NAME, integration_name=name, override=integration_variable_override
        )
        self.user = user or load_integration_variable(
            name=_CLOUDSQL_USER_NAME, integration_name=name, override=integration_variable_override
        )
        self.password = password or load_integration_variable(
            name=_CLOUDSQL_PASSWORD_NAME, integration_name=name, override=integration_variable_override
        )
        if engine_args is None:
            engine_args = {}
        if async_engine_args is None:
            async_engine_args = {}
        engine_args.setdefault("pool_size", 20)
        engine_args.setdefault("max_overflow", 60)
        async_engine_args.setdefault("pool_size", 20)
        async_engine_args.setdefault("max_overflow", 60)
        engine_args.setdefault(
            "connect_args",
            {
                "keepalives": 1,
                "keepalives_idle": 30,
                "keepalives_interval": 10,
                "keepalives_count": 5,
            },
        )
        # We set the default isolation level to autocommit since the SQL sources are read-only, and thus
        # transactions are not needed
        # Setting the isolation level on the engine, instead of the connection, avoids
        # a DBAPI statement to reset the transactional level back to the default before returning the
        # connection to the pool
        engine_args.setdefault("isolation_level", os.environ.get("CHALK_SQL_ISOLATION_LEVEL", "AUTOCOMMIT"))
        async_engine_args.setdefault("isolation_level", os.environ.get("CHALK_SQL_ISOLATION_LEVEL", "AUTOCOMMIT"))
        BaseSQLSource.__init__(self, name=name, engine_args=engine_args, async_engine_args=async_engine_args)

    def get_sqlglot_dialect(self) -> str | None:
        return "postgres"

    def local_engine_url(self) -> URL:
        from sqlalchemy.engine.url import URL

        return URL.create(
            drivername="postgresql+psycopg2",
            username=self.user,
            password=self.password,
            host="",
            query={"host": "{}/{}/.s.PGSQL.5432".format("/cloudsql", self.instance_name)},
            database=self.db,
        )

    def async_local_engine_url(self) -> URL:
        from sqlalchemy.engine.url import URL

        return URL.create(
            drivername="postgresql+psycopg",
            username=self.user,
            password=self.password,
            host="",
            query={"host": "{}/{}/.s.PGSQL.5432".format("/cloudsql", self.instance_name)},
            database=self.db,
        )

    def _recreate_integration_variables(self) -> dict[str, str]:
        return {
            k: v
            for k, v in [
                create_integration_variable(_CLOUDSQL_INSTANCE_NAME_NAME, self.name, self.instance_name),
                create_integration_variable(_CLOUDSQL_DATABASE_NAME, self.name, self.db),
                create_integration_variable(_CLOUDSQL_USER_NAME, self.name, self.user),
                create_integration_variable(_CLOUDSQL_PASSWORD_NAME, self.name, self.password),
            ]
            if v is not None
        }



from chalk._gen.chalk.auth.v1 import permissions_pb2 as _permissions_pb2
from chalk._gen.chalk.graph.v1 import graph_pb2 as _graph_pb2
from chalk._gen.chalk.lsp.v1 import lsp_pb2 as _lsp_pb2
from chalk._gen.chalk.nodepools.v1 import gke_pb2 as _gke_pb2
from chalk._gen.chalk.nodepools.v1 import karpenter_pb2 as _karpenter_pb2
from chalk._gen.chalk.server.v1 import deployment_pb2 as _deployment_pb2
from chalk._gen.chalk.server.v1 import log_pb2 as _log_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class DeploymentBuildStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DEPLOYMENT_BUILD_STATUS_UNSPECIFIED: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_UNKNOWN: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_PENDING: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_QUEUED: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_WORKING: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_SUCCESS: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_FAILURE: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_INTERNAL_ERROR: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_TIMEOUT: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_CANCELLED: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_EXPIRED: _ClassVar[DeploymentBuildStatus]
    DEPLOYMENT_BUILD_STATUS_BOOT_ERRORS: _ClassVar[DeploymentBuildStatus]

class BranchScalingState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    BRANCH_SCALING_STATE_UNSPECIFIED: _ClassVar[BranchScalingState]
    BRANCH_SCALING_STATE_SUCCESS: _ClassVar[BranchScalingState]
    BRANCH_SCALING_STATE_IN_PROGRESS: _ClassVar[BranchScalingState]

DEPLOYMENT_BUILD_STATUS_UNSPECIFIED: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_UNKNOWN: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_PENDING: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_QUEUED: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_WORKING: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_SUCCESS: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_FAILURE: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_INTERNAL_ERROR: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_TIMEOUT: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_CANCELLED: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_EXPIRED: DeploymentBuildStatus
DEPLOYMENT_BUILD_STATUS_BOOT_ERRORS: DeploymentBuildStatus
BRANCH_SCALING_STATE_UNSPECIFIED: BranchScalingState
BRANCH_SCALING_STATE_SUCCESS: BranchScalingState
BRANCH_SCALING_STATE_IN_PROGRESS: BranchScalingState

class ActivateDeploymentTarget(_message.Message):
    __slots__ = ("service_kind", "resource_group_name")
    SERVICE_KIND_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    service_kind: str
    resource_group_name: str
    def __init__(self, service_kind: _Optional[str] = ..., resource_group_name: _Optional[str] = ...) -> None: ...

class ActivateDeploymentRequest(_message.Message):
    __slots__ = ("existing_deployment_id", "targets")
    EXISTING_DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    TARGETS_FIELD_NUMBER: _ClassVar[int]
    existing_deployment_id: str
    targets: _containers.RepeatedCompositeFieldContainer[ActivateDeploymentTarget]
    def __init__(
        self,
        existing_deployment_id: _Optional[str] = ...,
        targets: _Optional[_Iterable[_Union[ActivateDeploymentTarget, _Mapping]]] = ...,
    ) -> None: ...

class ActivateDeploymentResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class IndexDeploymentRequest(_message.Message):
    __slots__ = ("existing_deployment_id",)
    EXISTING_DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    existing_deployment_id: str
    def __init__(self, existing_deployment_id: _Optional[str] = ...) -> None: ...

class IndexDeploymentResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeployKubeComponentsRequest(_message.Message):
    __slots__ = ("existing_deployment_id", "targets")
    EXISTING_DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    TARGETS_FIELD_NUMBER: _ClassVar[int]
    existing_deployment_id: str
    targets: _containers.RepeatedCompositeFieldContainer[ActivateDeploymentTarget]
    def __init__(
        self,
        existing_deployment_id: _Optional[str] = ...,
        targets: _Optional[_Iterable[_Union[ActivateDeploymentTarget, _Mapping]]] = ...,
    ) -> None: ...

class DeployKubeComponentsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RebuildDeploymentRequest(_message.Message):
    __slots__ = ("existing_deployment_id", "new_image_tag", "base_image_override", "enable_profiling")
    EXISTING_DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    NEW_IMAGE_TAG_FIELD_NUMBER: _ClassVar[int]
    BASE_IMAGE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    ENABLE_PROFILING_FIELD_NUMBER: _ClassVar[int]
    existing_deployment_id: str
    new_image_tag: str
    base_image_override: str
    enable_profiling: bool
    def __init__(
        self,
        existing_deployment_id: _Optional[str] = ...,
        new_image_tag: _Optional[str] = ...,
        base_image_override: _Optional[str] = ...,
        enable_profiling: bool = ...,
    ) -> None: ...

class RebuildDeploymentResponse(_message.Message):
    __slots__ = ("build_id",)
    BUILD_ID_FIELD_NUMBER: _ClassVar[int]
    build_id: str
    def __init__(self, build_id: _Optional[str] = ...) -> None: ...

class RedeployDeploymentRequest(_message.Message):
    __slots__ = ("existing_deployment_id", "enable_profiling", "deployment_tags", "base_image_override")
    EXISTING_DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    ENABLE_PROFILING_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_TAGS_FIELD_NUMBER: _ClassVar[int]
    BASE_IMAGE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    existing_deployment_id: str
    enable_profiling: bool
    deployment_tags: _containers.RepeatedScalarFieldContainer[str]
    base_image_override: str
    def __init__(
        self,
        existing_deployment_id: _Optional[str] = ...,
        enable_profiling: bool = ...,
        deployment_tags: _Optional[_Iterable[str]] = ...,
        base_image_override: _Optional[str] = ...,
    ) -> None: ...

class RedeployDeploymentResponse(_message.Message):
    __slots__ = ("build_id", "deployment_id")
    BUILD_ID_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    build_id: str
    deployment_id: str
    def __init__(self, build_id: _Optional[str] = ..., deployment_id: _Optional[str] = ...) -> None: ...

class UploadSourceRequest(_message.Message):
    __slots__ = (
        "deployment_id",
        "archive",
        "no_promote",
        "dependency_hash",
        "base_image_override",
        "use_grpc",
        "enable_profiling",
    )
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    ARCHIVE_FIELD_NUMBER: _ClassVar[int]
    NO_PROMOTE_FIELD_NUMBER: _ClassVar[int]
    DEPENDENCY_HASH_FIELD_NUMBER: _ClassVar[int]
    BASE_IMAGE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    USE_GRPC_FIELD_NUMBER: _ClassVar[int]
    ENABLE_PROFILING_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    archive: bytes
    no_promote: bool
    dependency_hash: str
    base_image_override: str
    use_grpc: bool
    enable_profiling: bool
    def __init__(
        self,
        deployment_id: _Optional[str] = ...,
        archive: _Optional[bytes] = ...,
        no_promote: bool = ...,
        dependency_hash: _Optional[str] = ...,
        base_image_override: _Optional[str] = ...,
        use_grpc: bool = ...,
        enable_profiling: bool = ...,
    ) -> None: ...

class UploadSourceResponse(_message.Message):
    __slots__ = ("status", "progress_url")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_URL_FIELD_NUMBER: _ClassVar[int]
    status: str
    progress_url: str
    def __init__(self, status: _Optional[str] = ..., progress_url: _Optional[str] = ...) -> None: ...

class LintSourceRequest(_message.Message):
    __slots__ = ("archive",)
    ARCHIVE_FIELD_NUMBER: _ClassVar[int]
    archive: bytes
    def __init__(self, archive: _Optional[bytes] = ...) -> None: ...

class LintSourceResponse(_message.Message):
    __slots__ = ("graph", "lsp")
    GRAPH_FIELD_NUMBER: _ClassVar[int]
    LSP_FIELD_NUMBER: _ClassVar[int]
    graph: _graph_pb2.Graph
    lsp: _lsp_pb2.LSP
    def __init__(
        self,
        graph: _Optional[_Union[_graph_pb2.Graph, _Mapping]] = ...,
        lsp: _Optional[_Union[_lsp_pb2.LSP, _Mapping]] = ...,
    ) -> None: ...

class GetDeploymentStepsRequest(_message.Message):
    __slots__ = ("deployment_id",)
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    def __init__(self, deployment_id: _Optional[str] = ...) -> None: ...

class DeploymentBuildStep(_message.Message):
    __slots__ = ("id", "display_name", "status", "start_time", "end_time")
    ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    id: str
    display_name: str
    status: DeploymentBuildStatus
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    def __init__(
        self,
        id: _Optional[str] = ...,
        display_name: _Optional[str] = ...,
        status: _Optional[_Union[DeploymentBuildStatus, str]] = ...,
        start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
    ) -> None: ...

class GetDeploymentStepsResponse(_message.Message):
    __slots__ = ("steps", "deployment")
    STEPS_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_FIELD_NUMBER: _ClassVar[int]
    steps: _containers.RepeatedCompositeFieldContainer[DeploymentBuildStep]
    deployment: _deployment_pb2.Deployment
    def __init__(
        self,
        steps: _Optional[_Iterable[_Union[DeploymentBuildStep, _Mapping]]] = ...,
        deployment: _Optional[_Union[_deployment_pb2.Deployment, _Mapping]] = ...,
    ) -> None: ...

class GetDeploymentLogsRequest(_message.Message):
    __slots__ = ("deployment_id",)
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    def __init__(self, deployment_id: _Optional[str] = ...) -> None: ...

class GetDeploymentLogsResponse(_message.Message):
    __slots__ = ("logs",)
    LOGS_FIELD_NUMBER: _ClassVar[int]
    logs: _containers.RepeatedCompositeFieldContainer[_log_pb2.LogEntry]
    def __init__(self, logs: _Optional[_Iterable[_Union[_log_pb2.LogEntry, _Mapping]]] = ...) -> None: ...

class GetClusterTimescaleDBRequest(_message.Message):
    __slots__ = ("environment_id",)
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    def __init__(self, environment_id: _Optional[str] = ...) -> None: ...

class GetClusterTimescaleDBResponse(_message.Message):
    __slots__ = ("id", "specs_string", "created_at", "updated_at", "specs")
    ID_FIELD_NUMBER: _ClassVar[int]
    SPECS_STRING_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    SPECS_FIELD_NUMBER: _ClassVar[int]
    id: str
    specs_string: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    specs: ClusterTimescaleSpecs
    def __init__(
        self,
        id: _Optional[str] = ...,
        specs_string: _Optional[str] = ...,
        created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        specs: _Optional[_Union[ClusterTimescaleSpecs, _Mapping]] = ...,
    ) -> None: ...

class GetClusterGatewayRequest(_message.Message):
    __slots__ = ("environment_id",)
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    def __init__(self, environment_id: _Optional[str] = ...) -> None: ...

class GetClusterGatewayResponse(_message.Message):
    __slots__ = ("id", "specs_string", "created_at", "updated_at", "specs")
    ID_FIELD_NUMBER: _ClassVar[int]
    SPECS_STRING_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    SPECS_FIELD_NUMBER: _ClassVar[int]
    id: str
    specs_string: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    specs: EnvoyGatewaySpecs
    def __init__(
        self,
        id: _Optional[str] = ...,
        specs_string: _Optional[str] = ...,
        created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        specs: _Optional[_Union[EnvoyGatewaySpecs, _Mapping]] = ...,
    ) -> None: ...

class BackgroundPersistence(_message.Message):
    __slots__ = ("id", "kind", "specs_string", "created_at", "updated_at", "specs")
    ID_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    SPECS_STRING_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    SPECS_FIELD_NUMBER: _ClassVar[int]
    id: str
    kind: str
    specs_string: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    specs: BackgroundPersistenceDeploymentSpecs
    def __init__(
        self,
        id: _Optional[str] = ...,
        kind: _Optional[str] = ...,
        specs_string: _Optional[str] = ...,
        created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        specs: _Optional[_Union[BackgroundPersistenceDeploymentSpecs, _Mapping]] = ...,
    ) -> None: ...

class GetClusterBackgroundPersistenceRequest(_message.Message):
    __slots__ = ("environment_id",)
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    environment_id: str
    def __init__(self, environment_id: _Optional[str] = ...) -> None: ...

class GetClusterBackgroundPersistenceResponse(_message.Message):
    __slots__ = ("background_persistence",)
    BACKGROUND_PERSISTENCE_FIELD_NUMBER: _ClassVar[int]
    background_persistence: BackgroundPersistence
    def __init__(self, background_persistence: _Optional[_Union[BackgroundPersistence, _Mapping]] = ...) -> None: ...

class CreateClusterTimescaleDBRequest(_message.Message):
    __slots__ = ("environment_id", "environment_ids", "specs_string", "specs")
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_IDS_FIELD_NUMBER: _ClassVar[int]
    SPECS_STRING_FIELD_NUMBER: _ClassVar[int]
    SPECS_FIELD_NUMBER: _ClassVar[int]
    environment_id: _containers.RepeatedScalarFieldContainer[str]
    environment_ids: _containers.RepeatedScalarFieldContainer[str]
    specs_string: str
    specs: ClusterTimescaleSpecs
    def __init__(
        self,
        environment_id: _Optional[_Iterable[str]] = ...,
        environment_ids: _Optional[_Iterable[str]] = ...,
        specs_string: _Optional[str] = ...,
        specs: _Optional[_Union[ClusterTimescaleSpecs, _Mapping]] = ...,
    ) -> None: ...

class KubeResourceConfig(_message.Message):
    __slots__ = ("cpu", "memory", "ephemeral_storage", "storage")
    CPU_FIELD_NUMBER: _ClassVar[int]
    MEMORY_FIELD_NUMBER: _ClassVar[int]
    EPHEMERAL_STORAGE_FIELD_NUMBER: _ClassVar[int]
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    cpu: str
    memory: str
    ephemeral_storage: str
    storage: str
    def __init__(
        self,
        cpu: _Optional[str] = ...,
        memory: _Optional[str] = ...,
        ephemeral_storage: _Optional[str] = ...,
        storage: _Optional[str] = ...,
    ) -> None: ...

class ClusterTimescaleSpecs(_message.Message):
    __slots__ = (
        "timescale_image",
        "database_name",
        "database_replicas",
        "storage",
        "storage_class",
        "namespace",
        "request",
        "limit",
        "connection_pool_replicas",
        "connection_pool_max_connections",
        "connection_pool_size",
        "connection_pool_mode",
        "backup_bucket",
        "backup_iam_role_arn",
        "secret_name",
        "internal",
        "service_type",
        "postgres_parameters",
        "include_chalk_node_selector",
        "backup_gcp_service_account",
        "instance_type",
    )
    class PostgresParametersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

    TIMESCALE_IMAGE_FIELD_NUMBER: _ClassVar[int]
    DATABASE_NAME_FIELD_NUMBER: _ClassVar[int]
    DATABASE_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    STORAGE_FIELD_NUMBER: _ClassVar[int]
    STORAGE_CLASS_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_POOL_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_POOL_MAX_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_POOL_SIZE_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_POOL_MODE_FIELD_NUMBER: _ClassVar[int]
    BACKUP_BUCKET_FIELD_NUMBER: _ClassVar[int]
    BACKUP_IAM_ROLE_ARN_FIELD_NUMBER: _ClassVar[int]
    SECRET_NAME_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_FIELD_NUMBER: _ClassVar[int]
    SERVICE_TYPE_FIELD_NUMBER: _ClassVar[int]
    POSTGRES_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_CHALK_NODE_SELECTOR_FIELD_NUMBER: _ClassVar[int]
    BACKUP_GCP_SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    timescale_image: str
    database_name: str
    database_replicas: int
    storage: str
    storage_class: str
    namespace: str
    request: KubeResourceConfig
    limit: KubeResourceConfig
    connection_pool_replicas: int
    connection_pool_max_connections: str
    connection_pool_size: str
    connection_pool_mode: str
    backup_bucket: str
    backup_iam_role_arn: str
    secret_name: str
    internal: bool
    service_type: str
    postgres_parameters: _containers.ScalarMap[str, str]
    include_chalk_node_selector: bool
    backup_gcp_service_account: str
    instance_type: str
    def __init__(
        self,
        timescale_image: _Optional[str] = ...,
        database_name: _Optional[str] = ...,
        database_replicas: _Optional[int] = ...,
        storage: _Optional[str] = ...,
        storage_class: _Optional[str] = ...,
        namespace: _Optional[str] = ...,
        request: _Optional[_Union[KubeResourceConfig, _Mapping]] = ...,
        limit: _Optional[_Union[KubeResourceConfig, _Mapping]] = ...,
        connection_pool_replicas: _Optional[int] = ...,
        connection_pool_max_connections: _Optional[str] = ...,
        connection_pool_size: _Optional[str] = ...,
        connection_pool_mode: _Optional[str] = ...,
        backup_bucket: _Optional[str] = ...,
        backup_iam_role_arn: _Optional[str] = ...,
        secret_name: _Optional[str] = ...,
        internal: bool = ...,
        service_type: _Optional[str] = ...,
        postgres_parameters: _Optional[_Mapping[str, str]] = ...,
        include_chalk_node_selector: bool = ...,
        backup_gcp_service_account: _Optional[str] = ...,
        instance_type: _Optional[str] = ...,
    ) -> None: ...

class CreateClusterTimescaleDBResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MigrateClusterTimescaleDBRequest(_message.Message):
    __slots__ = ("cluster_timescale_id", "migration_image", "environment_ids")
    CLUSTER_TIMESCALE_ID_FIELD_NUMBER: _ClassVar[int]
    MIGRATION_IMAGE_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_IDS_FIELD_NUMBER: _ClassVar[int]
    cluster_timescale_id: str
    migration_image: str
    environment_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(
        self,
        cluster_timescale_id: _Optional[str] = ...,
        migration_image: _Optional[str] = ...,
        environment_ids: _Optional[_Iterable[str]] = ...,
    ) -> None: ...

class MigrateClusterTimescaleDBResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CreateClusterGatewayRequest(_message.Message):
    __slots__ = ("environment_id", "environment_ids", "specs_string", "specs")
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_IDS_FIELD_NUMBER: _ClassVar[int]
    SPECS_STRING_FIELD_NUMBER: _ClassVar[int]
    SPECS_FIELD_NUMBER: _ClassVar[int]
    environment_id: _containers.RepeatedScalarFieldContainer[str]
    environment_ids: _containers.RepeatedScalarFieldContainer[str]
    specs_string: str
    specs: EnvoyGatewaySpecs
    def __init__(
        self,
        environment_id: _Optional[_Iterable[str]] = ...,
        environment_ids: _Optional[_Iterable[str]] = ...,
        specs_string: _Optional[str] = ...,
        specs: _Optional[_Union[EnvoyGatewaySpecs, _Mapping]] = ...,
    ) -> None: ...

class EnvoyGatewaySpecs(_message.Message):
    __slots__ = (
        "namespace",
        "gateway_name",
        "gateway_class_name",
        "listeners",
        "config",
        "include_chalk_node_selector",
    )
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    GATEWAY_NAME_FIELD_NUMBER: _ClassVar[int]
    GATEWAY_CLASS_NAME_FIELD_NUMBER: _ClassVar[int]
    LISTENERS_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_CHALK_NODE_SELECTOR_FIELD_NUMBER: _ClassVar[int]
    namespace: str
    gateway_name: str
    gateway_class_name: str
    listeners: _containers.RepeatedCompositeFieldContainer[EnvoyGatewayListener]
    config: GatewayProviderConfig
    include_chalk_node_selector: bool
    def __init__(
        self,
        namespace: _Optional[str] = ...,
        gateway_name: _Optional[str] = ...,
        gateway_class_name: _Optional[str] = ...,
        listeners: _Optional[_Iterable[_Union[EnvoyGatewayListener, _Mapping]]] = ...,
        config: _Optional[_Union[GatewayProviderConfig, _Mapping]] = ...,
        include_chalk_node_selector: bool = ...,
    ) -> None: ...

class EnvoyGatewayListener(_message.Message):
    __slots__ = ("port", "protocol", "name", "allowed_routes")
    PORT_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_ROUTES_FIELD_NUMBER: _ClassVar[int]
    port: int
    protocol: str
    name: str
    allowed_routes: EnvoyGatewayAllowedRoutes
    def __init__(
        self,
        port: _Optional[int] = ...,
        protocol: _Optional[str] = ...,
        name: _Optional[str] = ...,
        allowed_routes: _Optional[_Union[EnvoyGatewayAllowedRoutes, _Mapping]] = ...,
    ) -> None: ...

class EnvoyGatewayAllowedRoutes(_message.Message):
    __slots__ = ("namespaces",)
    NAMESPACES_FIELD_NUMBER: _ClassVar[int]
    namespaces: EnvoyGatewayAllowedNamespaces
    def __init__(self, namespaces: _Optional[_Union[EnvoyGatewayAllowedNamespaces, _Mapping]] = ...) -> None: ...

class EnvoyGatewayAllowedNamespaces(_message.Message):
    __slots__ = ()
    FROM_FIELD_NUMBER: _ClassVar[int]
    def __init__(self, **kwargs) -> None: ...

class GatewayProviderConfig(_message.Message):
    __slots__ = ("envoy", "gcp")
    ENVOY_FIELD_NUMBER: _ClassVar[int]
    GCP_FIELD_NUMBER: _ClassVar[int]
    envoy: EnvoyGatewayProviderConfig
    gcp: GCPGatewayProviderConfig
    def __init__(
        self,
        envoy: _Optional[_Union[EnvoyGatewayProviderConfig, _Mapping]] = ...,
        gcp: _Optional[_Union[GCPGatewayProviderConfig, _Mapping]] = ...,
    ) -> None: ...

class EnvoyGatewayProviderConfig(_message.Message):
    __slots__ = ("timeout_duration", "dns_hostname", "replicas", "min_available")
    TIMEOUT_DURATION_FIELD_NUMBER: _ClassVar[int]
    DNS_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    REPLICAS_FIELD_NUMBER: _ClassVar[int]
    MIN_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    timeout_duration: str
    dns_hostname: str
    replicas: int
    min_available: int
    def __init__(
        self,
        timeout_duration: _Optional[str] = ...,
        dns_hostname: _Optional[str] = ...,
        replicas: _Optional[int] = ...,
        min_available: _Optional[int] = ...,
    ) -> None: ...

class GCPGatewayProviderConfig(_message.Message):
    __slots__ = ("dns_hostname",)
    DNS_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    dns_hostname: str
    def __init__(self, dns_hostname: _Optional[str] = ...) -> None: ...

class CreateClusterGatewayResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CreateClusterBackgroundPersistenceRequest(_message.Message):
    __slots__ = ("environment_ids", "specs_string", "specs")
    ENVIRONMENT_IDS_FIELD_NUMBER: _ClassVar[int]
    SPECS_STRING_FIELD_NUMBER: _ClassVar[int]
    SPECS_FIELD_NUMBER: _ClassVar[int]
    environment_ids: _containers.RepeatedScalarFieldContainer[str]
    specs_string: str
    specs: BackgroundPersistenceDeploymentSpecs
    def __init__(
        self,
        environment_ids: _Optional[_Iterable[str]] = ...,
        specs_string: _Optional[str] = ...,
        specs: _Optional[_Union[BackgroundPersistenceDeploymentSpecs, _Mapping]] = ...,
    ) -> None: ...

class BackgroundPersistenceCommonSpecs(_message.Message):
    __slots__ = (
        "namespace",
        "bus_writer_image_go",
        "bus_writer_image_python",
        "bus_writer_image_bswl",
        "service_account_name",
        "bus_backend",
        "secret_client",
        "bigquery_parquet_upload_subscription_id",
        "bigquery_streaming_write_subscription_id",
        "bigquery_streaming_write_topic",
        "bigquery_upload_bucket",
        "bigquery_upload_topic",
        "google_cloud_project",
        "kafka_dlq_topic",
        "metrics_bus_subscription_id",
        "metrics_bus_topic_id",
        "operation_subscription_id",
        "query_log_result_topic",
        "query_log_subscription_id",
        "result_bus_metrics_subscription_id",
        "result_bus_offline_store_subscription_id",
        "result_bus_online_store_subscription_id",
        "result_bus_topic_id",
        "usage_bus_topic_id",
        "usage_events_subscription_id",
        "bq_upload_bucket",
        "bq_upload_topic",
        "include_chalk_node_selector",
        "bus_writer_image_rust",
    )
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    BUS_WRITER_IMAGE_GO_FIELD_NUMBER: _ClassVar[int]
    BUS_WRITER_IMAGE_PYTHON_FIELD_NUMBER: _ClassVar[int]
    BUS_WRITER_IMAGE_BSWL_FIELD_NUMBER: _ClassVar[int]
    SERVICE_ACCOUNT_NAME_FIELD_NUMBER: _ClassVar[int]
    BUS_BACKEND_FIELD_NUMBER: _ClassVar[int]
    SECRET_CLIENT_FIELD_NUMBER: _ClassVar[int]
    BIGQUERY_PARQUET_UPLOAD_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    BIGQUERY_STREAMING_WRITE_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    BIGQUERY_STREAMING_WRITE_TOPIC_FIELD_NUMBER: _ClassVar[int]
    BIGQUERY_UPLOAD_BUCKET_FIELD_NUMBER: _ClassVar[int]
    BIGQUERY_UPLOAD_TOPIC_FIELD_NUMBER: _ClassVar[int]
    GOOGLE_CLOUD_PROJECT_FIELD_NUMBER: _ClassVar[int]
    KAFKA_DLQ_TOPIC_FIELD_NUMBER: _ClassVar[int]
    METRICS_BUS_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    METRICS_BUS_TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    OPERATION_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    QUERY_LOG_RESULT_TOPIC_FIELD_NUMBER: _ClassVar[int]
    QUERY_LOG_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_BUS_METRICS_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_BUS_OFFLINE_STORE_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_BUS_ONLINE_STORE_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_BUS_TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    USAGE_BUS_TOPIC_ID_FIELD_NUMBER: _ClassVar[int]
    USAGE_EVENTS_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    BQ_UPLOAD_BUCKET_FIELD_NUMBER: _ClassVar[int]
    BQ_UPLOAD_TOPIC_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_CHALK_NODE_SELECTOR_FIELD_NUMBER: _ClassVar[int]
    BUS_WRITER_IMAGE_RUST_FIELD_NUMBER: _ClassVar[int]
    namespace: str
    bus_writer_image_go: str
    bus_writer_image_python: str
    bus_writer_image_bswl: str
    service_account_name: str
    bus_backend: str
    secret_client: str
    bigquery_parquet_upload_subscription_id: str
    bigquery_streaming_write_subscription_id: str
    bigquery_streaming_write_topic: str
    bigquery_upload_bucket: str
    bigquery_upload_topic: str
    google_cloud_project: str
    kafka_dlq_topic: str
    metrics_bus_subscription_id: str
    metrics_bus_topic_id: str
    operation_subscription_id: str
    query_log_result_topic: str
    query_log_subscription_id: str
    result_bus_metrics_subscription_id: str
    result_bus_offline_store_subscription_id: str
    result_bus_online_store_subscription_id: str
    result_bus_topic_id: str
    usage_bus_topic_id: str
    usage_events_subscription_id: str
    bq_upload_bucket: str
    bq_upload_topic: str
    include_chalk_node_selector: bool
    bus_writer_image_rust: str
    def __init__(
        self,
        namespace: _Optional[str] = ...,
        bus_writer_image_go: _Optional[str] = ...,
        bus_writer_image_python: _Optional[str] = ...,
        bus_writer_image_bswl: _Optional[str] = ...,
        service_account_name: _Optional[str] = ...,
        bus_backend: _Optional[str] = ...,
        secret_client: _Optional[str] = ...,
        bigquery_parquet_upload_subscription_id: _Optional[str] = ...,
        bigquery_streaming_write_subscription_id: _Optional[str] = ...,
        bigquery_streaming_write_topic: _Optional[str] = ...,
        bigquery_upload_bucket: _Optional[str] = ...,
        bigquery_upload_topic: _Optional[str] = ...,
        google_cloud_project: _Optional[str] = ...,
        kafka_dlq_topic: _Optional[str] = ...,
        metrics_bus_subscription_id: _Optional[str] = ...,
        metrics_bus_topic_id: _Optional[str] = ...,
        operation_subscription_id: _Optional[str] = ...,
        query_log_result_topic: _Optional[str] = ...,
        query_log_subscription_id: _Optional[str] = ...,
        result_bus_metrics_subscription_id: _Optional[str] = ...,
        result_bus_offline_store_subscription_id: _Optional[str] = ...,
        result_bus_online_store_subscription_id: _Optional[str] = ...,
        result_bus_topic_id: _Optional[str] = ...,
        usage_bus_topic_id: _Optional[str] = ...,
        usage_events_subscription_id: _Optional[str] = ...,
        bq_upload_bucket: _Optional[str] = ...,
        bq_upload_topic: _Optional[str] = ...,
        include_chalk_node_selector: bool = ...,
        bus_writer_image_rust: _Optional[str] = ...,
    ) -> None: ...

class BackgroundPersistenceWriterHpaSpecs(_message.Message):
    __slots__ = ("hpa_pubsub_subscription_id", "hpa_min_replicas", "hpa_max_replicas", "hpa_target_average_value")
    HPA_PUBSUB_SUBSCRIPTION_ID_FIELD_NUMBER: _ClassVar[int]
    HPA_MIN_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    HPA_MAX_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    HPA_TARGET_AVERAGE_VALUE_FIELD_NUMBER: _ClassVar[int]
    hpa_pubsub_subscription_id: str
    hpa_min_replicas: int
    hpa_max_replicas: int
    hpa_target_average_value: int
    def __init__(
        self,
        hpa_pubsub_subscription_id: _Optional[str] = ...,
        hpa_min_replicas: _Optional[int] = ...,
        hpa_max_replicas: _Optional[int] = ...,
        hpa_target_average_value: _Optional[int] = ...,
    ) -> None: ...

class BackgroundPersistenceWriterSpecs(_message.Message):
    __slots__ = (
        "name",
        "image_override",
        "hpa_specs",
        "gke_spot",
        "load_writer_configmap",
        "version",
        "request",
        "limit",
        "bus_subscriber_type",
        "default_replica_count",
        "kafka_consumer_group_override",
        "max_batch_size",
        "message_processing_concurrency",
        "metadata_sql_ssl_ca_cert_secret",
        "metadata_sql_ssl_client_cert_secret",
        "metadata_sql_ssl_client_key_secret",
        "metadata_sql_uri_secret",
        "offline_store_inserter_db_type",
        "storage_cache_prefix",
        "usage_store_uri",
        "results_writer_skip_producing_feature_metrics",
        "query_table_write_drop_ratio",
    )
    NAME_FIELD_NUMBER: _ClassVar[int]
    IMAGE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    HPA_SPECS_FIELD_NUMBER: _ClassVar[int]
    GKE_SPOT_FIELD_NUMBER: _ClassVar[int]
    LOAD_WRITER_CONFIGMAP_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    BUS_SUBSCRIBER_TYPE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_REPLICA_COUNT_FIELD_NUMBER: _ClassVar[int]
    KAFKA_CONSUMER_GROUP_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    MAX_BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_PROCESSING_CONCURRENCY_FIELD_NUMBER: _ClassVar[int]
    METADATA_SQL_SSL_CA_CERT_SECRET_FIELD_NUMBER: _ClassVar[int]
    METADATA_SQL_SSL_CLIENT_CERT_SECRET_FIELD_NUMBER: _ClassVar[int]
    METADATA_SQL_SSL_CLIENT_KEY_SECRET_FIELD_NUMBER: _ClassVar[int]
    METADATA_SQL_URI_SECRET_FIELD_NUMBER: _ClassVar[int]
    OFFLINE_STORE_INSERTER_DB_TYPE_FIELD_NUMBER: _ClassVar[int]
    STORAGE_CACHE_PREFIX_FIELD_NUMBER: _ClassVar[int]
    USAGE_STORE_URI_FIELD_NUMBER: _ClassVar[int]
    RESULTS_WRITER_SKIP_PRODUCING_FEATURE_METRICS_FIELD_NUMBER: _ClassVar[int]
    QUERY_TABLE_WRITE_DROP_RATIO_FIELD_NUMBER: _ClassVar[int]
    name: str
    image_override: str
    hpa_specs: BackgroundPersistenceWriterHpaSpecs
    gke_spot: bool
    load_writer_configmap: bool
    version: str
    request: KubeResourceConfig
    limit: KubeResourceConfig
    bus_subscriber_type: str
    default_replica_count: int
    kafka_consumer_group_override: str
    max_batch_size: int
    message_processing_concurrency: int
    metadata_sql_ssl_ca_cert_secret: str
    metadata_sql_ssl_client_cert_secret: str
    metadata_sql_ssl_client_key_secret: str
    metadata_sql_uri_secret: str
    offline_store_inserter_db_type: str
    storage_cache_prefix: str
    usage_store_uri: str
    results_writer_skip_producing_feature_metrics: bool
    query_table_write_drop_ratio: str
    def __init__(
        self,
        name: _Optional[str] = ...,
        image_override: _Optional[str] = ...,
        hpa_specs: _Optional[_Union[BackgroundPersistenceWriterHpaSpecs, _Mapping]] = ...,
        gke_spot: bool = ...,
        load_writer_configmap: bool = ...,
        version: _Optional[str] = ...,
        request: _Optional[_Union[KubeResourceConfig, _Mapping]] = ...,
        limit: _Optional[_Union[KubeResourceConfig, _Mapping]] = ...,
        bus_subscriber_type: _Optional[str] = ...,
        default_replica_count: _Optional[int] = ...,
        kafka_consumer_group_override: _Optional[str] = ...,
        max_batch_size: _Optional[int] = ...,
        message_processing_concurrency: _Optional[int] = ...,
        metadata_sql_ssl_ca_cert_secret: _Optional[str] = ...,
        metadata_sql_ssl_client_cert_secret: _Optional[str] = ...,
        metadata_sql_ssl_client_key_secret: _Optional[str] = ...,
        metadata_sql_uri_secret: _Optional[str] = ...,
        offline_store_inserter_db_type: _Optional[str] = ...,
        storage_cache_prefix: _Optional[str] = ...,
        usage_store_uri: _Optional[str] = ...,
        results_writer_skip_producing_feature_metrics: bool = ...,
        query_table_write_drop_ratio: _Optional[str] = ...,
    ) -> None: ...

class BackgroundPersistenceDeploymentSpecs(_message.Message):
    __slots__ = (
        "common_persistence_specs",
        "api_server_host",
        "kafka_sasl_secret",
        "metadata_provider",
        "kafka_bootstrap_servers",
        "kafka_security_protocol",
        "kafka_sasl_mechanism",
        "redis_is_clustered",
        "snowflake_storage_integration_name",
        "redis_lightning_supports_has_many",
        "insecure",
        "writers",
    )
    COMMON_PERSISTENCE_SPECS_FIELD_NUMBER: _ClassVar[int]
    API_SERVER_HOST_FIELD_NUMBER: _ClassVar[int]
    KAFKA_SASL_SECRET_FIELD_NUMBER: _ClassVar[int]
    METADATA_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    KAFKA_BOOTSTRAP_SERVERS_FIELD_NUMBER: _ClassVar[int]
    KAFKA_SECURITY_PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    KAFKA_SASL_MECHANISM_FIELD_NUMBER: _ClassVar[int]
    REDIS_IS_CLUSTERED_FIELD_NUMBER: _ClassVar[int]
    SNOWFLAKE_STORAGE_INTEGRATION_NAME_FIELD_NUMBER: _ClassVar[int]
    REDIS_LIGHTNING_SUPPORTS_HAS_MANY_FIELD_NUMBER: _ClassVar[int]
    INSECURE_FIELD_NUMBER: _ClassVar[int]
    WRITERS_FIELD_NUMBER: _ClassVar[int]
    common_persistence_specs: BackgroundPersistenceCommonSpecs
    api_server_host: str
    kafka_sasl_secret: str
    metadata_provider: str
    kafka_bootstrap_servers: str
    kafka_security_protocol: str
    kafka_sasl_mechanism: str
    redis_is_clustered: str
    snowflake_storage_integration_name: str
    redis_lightning_supports_has_many: bool
    insecure: bool
    writers: _containers.RepeatedCompositeFieldContainer[BackgroundPersistenceWriterSpecs]
    def __init__(
        self,
        common_persistence_specs: _Optional[_Union[BackgroundPersistenceCommonSpecs, _Mapping]] = ...,
        api_server_host: _Optional[str] = ...,
        kafka_sasl_secret: _Optional[str] = ...,
        metadata_provider: _Optional[str] = ...,
        kafka_bootstrap_servers: _Optional[str] = ...,
        kafka_security_protocol: _Optional[str] = ...,
        kafka_sasl_mechanism: _Optional[str] = ...,
        redis_is_clustered: _Optional[str] = ...,
        snowflake_storage_integration_name: _Optional[str] = ...,
        redis_lightning_supports_has_many: bool = ...,
        insecure: bool = ...,
        writers: _Optional[_Iterable[_Union[BackgroundPersistenceWriterSpecs, _Mapping]]] = ...,
    ) -> None: ...

class CreateClusterBackgroundPersistenceResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetSearchConfigRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetSearchConfigResponse(_message.Message):
    __slots__ = ("team_id", "team_api_key")
    TEAM_ID_FIELD_NUMBER: _ClassVar[int]
    TEAM_API_KEY_FIELD_NUMBER: _ClassVar[int]
    team_id: str
    team_api_key: str
    def __init__(self, team_id: _Optional[str] = ..., team_api_key: _Optional[str] = ...) -> None: ...

class UpdateEnvironmentVariablesRequest(_message.Message):
    __slots__ = ("environment_variables",)
    class EnvironmentVariablesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

    ENVIRONMENT_VARIABLES_FIELD_NUMBER: _ClassVar[int]
    environment_variables: _containers.ScalarMap[str, str]
    def __init__(self, environment_variables: _Optional[_Mapping[str, str]] = ...) -> None: ...

class UpdateEnvironmentVariablesResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class StartBranchRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class StartBranchResponse(_message.Message):
    __slots__ = ("state",)
    STATE_FIELD_NUMBER: _ClassVar[int]
    state: BranchScalingState
    def __init__(self, state: _Optional[_Union[BranchScalingState, str]] = ...) -> None: ...

class KafkaTopic(_message.Message):
    __slots__ = ("name", "partitions", "replication", "retention_ms")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    REPLICATION_FIELD_NUMBER: _ClassVar[int]
    RETENTION_MS_FIELD_NUMBER: _ClassVar[int]
    name: str
    partitions: int
    replication: int
    retention_ms: int
    def __init__(
        self,
        name: _Optional[str] = ...,
        partitions: _Optional[int] = ...,
        replication: _Optional[int] = ...,
        retention_ms: _Optional[int] = ...,
    ) -> None: ...

class CreateKafkaTopicsRequest(_message.Message):
    __slots__ = ("topics",)
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    topics: _containers.RepeatedCompositeFieldContainer[KafkaTopic]
    def __init__(self, topics: _Optional[_Iterable[_Union[KafkaTopic, _Mapping]]] = ...) -> None: ...

class CreateKafkaTopicsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetKafkaTopicsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetKafkaTopicsResponse(_message.Message):
    __slots__ = ("topics",)
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    topics: _containers.RepeatedCompositeFieldContainer[KafkaTopic]
    def __init__(self, topics: _Optional[_Iterable[_Union[KafkaTopic, _Mapping]]] = ...) -> None: ...

class GetNodepoolsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetNodepoolsResponse(_message.Message):
    __slots__ = ("karpenter_nodepools", "gke_nodepools")
    KARPENTER_NODEPOOLS_FIELD_NUMBER: _ClassVar[int]
    GKE_NODEPOOLS_FIELD_NUMBER: _ClassVar[int]
    karpenter_nodepools: _containers.RepeatedCompositeFieldContainer[_karpenter_pb2.KarpenterNodepool]
    gke_nodepools: _containers.RepeatedCompositeFieldContainer[_gke_pb2.GKENodePool]
    def __init__(
        self,
        karpenter_nodepools: _Optional[_Iterable[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]]] = ...,
        gke_nodepools: _Optional[_Iterable[_Union[_gke_pb2.GKENodePool, _Mapping]]] = ...,
    ) -> None: ...

class AddNodepoolRequest(_message.Message):
    __slots__ = ("karpenter_nodepool", "gke_nodepool")
    KARPENTER_NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    GKE_NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    karpenter_nodepool: _karpenter_pb2.KarpenterNodepool
    gke_nodepool: _gke_pb2.GKENodePool
    def __init__(
        self,
        karpenter_nodepool: _Optional[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]] = ...,
        gke_nodepool: _Optional[_Union[_gke_pb2.GKENodePool, _Mapping]] = ...,
    ) -> None: ...

class AddNodepoolResponse(_message.Message):
    __slots__ = ("karpenter_nodepool", "gke_nodepool")
    KARPENTER_NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    GKE_NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    karpenter_nodepool: _karpenter_pb2.KarpenterNodepool
    gke_nodepool: _gke_pb2.GKENodePool
    def __init__(
        self,
        karpenter_nodepool: _Optional[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]] = ...,
        gke_nodepool: _Optional[_Union[_gke_pb2.GKENodePool, _Mapping]] = ...,
    ) -> None: ...

class UpdateNodepoolRequest(_message.Message):
    __slots__ = ("name", "gke_nodepool", "karpenter_nodepool")
    NAME_FIELD_NUMBER: _ClassVar[int]
    GKE_NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    KARPENTER_NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    name: str
    gke_nodepool: _gke_pb2.GKENodePool
    karpenter_nodepool: _karpenter_pb2.KarpenterNodepool
    def __init__(
        self,
        name: _Optional[str] = ...,
        gke_nodepool: _Optional[_Union[_gke_pb2.GKENodePool, _Mapping]] = ...,
        karpenter_nodepool: _Optional[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]] = ...,
    ) -> None: ...

class UpdateNodepoolResponse(_message.Message):
    __slots__ = ("karpenter_nodepool", "gke_nodepool")
    KARPENTER_NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    GKE_NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    karpenter_nodepool: _karpenter_pb2.KarpenterNodepool
    gke_nodepool: _gke_pb2.GKENodePool
    def __init__(
        self,
        karpenter_nodepool: _Optional[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]] = ...,
        gke_nodepool: _Optional[_Union[_gke_pb2.GKENodePool, _Mapping]] = ...,
    ) -> None: ...

class DeleteNodepoolRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DeleteNodepoolResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetKarpenterNodepoolsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetKarpenterNodepoolsResponse(_message.Message):
    __slots__ = ("nodepools",)
    NODEPOOLS_FIELD_NUMBER: _ClassVar[int]
    nodepools: _containers.RepeatedCompositeFieldContainer[_karpenter_pb2.KarpenterNodepool]
    def __init__(
        self, nodepools: _Optional[_Iterable[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]]] = ...
    ) -> None: ...

class AddKarpenterNodepoolRequest(_message.Message):
    __slots__ = ("nodepool",)
    NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    nodepool: _karpenter_pb2.KarpenterNodepool
    def __init__(self, nodepool: _Optional[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]] = ...) -> None: ...

class AddKarpenterNodepoolResponse(_message.Message):
    __slots__ = ("nodepool",)
    NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    nodepool: _karpenter_pb2.KarpenterNodepool
    def __init__(self, nodepool: _Optional[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]] = ...) -> None: ...

class UpdateKarpenterNodepoolRequest(_message.Message):
    __slots__ = ("name", "nodepool")
    NAME_FIELD_NUMBER: _ClassVar[int]
    NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    name: str
    nodepool: _karpenter_pb2.KarpenterNodepool
    def __init__(
        self, name: _Optional[str] = ..., nodepool: _Optional[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]] = ...
    ) -> None: ...

class UpdateKarpenterNodepoolResponse(_message.Message):
    __slots__ = ("nodepool",)
    NODEPOOL_FIELD_NUMBER: _ClassVar[int]
    nodepool: _karpenter_pb2.KarpenterNodepool
    def __init__(self, nodepool: _Optional[_Union[_karpenter_pb2.KarpenterNodepool, _Mapping]] = ...) -> None: ...

class DeleteKarpenterNodepoolRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DeleteKarpenterNodepoolResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetKarpenterInstallationMetadataRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetKarpenterInstallationMetadataResponse(_message.Message):
    __slots__ = ("deployment_labels",)
    class DeploymentLabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

    DEPLOYMENT_LABELS_FIELD_NUMBER: _ClassVar[int]
    deployment_labels: _containers.ScalarMap[str, str]
    def __init__(self, deployment_labels: _Optional[_Mapping[str, str]] = ...) -> None: ...

class DeploymentTag(_message.Message):
    __slots__ = ("tag", "weight", "deployment_id", "mirror_weight")
    TAG_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    MIRROR_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    tag: str
    weight: int
    deployment_id: str
    mirror_weight: int
    def __init__(
        self,
        tag: _Optional[str] = ...,
        weight: _Optional[int] = ...,
        deployment_id: _Optional[str] = ...,
        mirror_weight: _Optional[int] = ...,
    ) -> None: ...

class GetTagWeightsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetTagWeightsResponse(_message.Message):
    __slots__ = ("tags",)
    TAGS_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedCompositeFieldContainer[DeploymentTag]
    def __init__(self, tags: _Optional[_Iterable[_Union[DeploymentTag, _Mapping]]] = ...) -> None: ...

class SetTagWeightsRequest(_message.Message):
    __slots__ = ("tags",)
    TAGS_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedCompositeFieldContainer[DeploymentTag]
    def __init__(self, tags: _Optional[_Iterable[_Union[DeploymentTag, _Mapping]]] = ...) -> None: ...

class SetTagWeightsResponse(_message.Message):
    __slots__ = ("tags",)
    TAGS_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedCompositeFieldContainer[DeploymentTag]
    def __init__(self, tags: _Optional[_Iterable[_Union[DeploymentTag, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/engine/v2/feature_values_chart.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chalk._gen.chalk.chart.v1 import densetimeserieschart_pb2 as chalk_dot_chart_dot_v1_dot_densetimeserieschart__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n*chalk/engine/v2/feature_values_chart.proto\x12\x0f\x63halk.engine.v2\x1a)chalk/chart/v1/densetimeserieschart.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto"F\n$FeatureValuePercentileWindowFunction\x12\x1e\n\npercentile\x18\x01 \x01(\x01R\npercentile"\xdd\x02\n\x12\x46\x65\x61tureValueSeries\x12\x1f\n\x0b\x66\x65\x61ture_fqn\x18\x01 \x01(\tR\nfeatureFqn\x12&\n\x0cseries_title\x18\x02 \x01(\tH\x01R\x0bseriesTitle\x88\x01\x01\x12\x63\n\x14\x62\x61se_window_function\x18\x03 \x01(\x0e\x32/.chalk.engine.v2.FeatureValueBaseWindowFunctionH\x00R\x12\x62\x61seWindowFunction\x12u\n\x1apercentile_window_function\x18\x04 \x01(\x0b\x32\x35.chalk.engine.v2.FeatureValuePercentileWindowFunctionH\x00R\x18percentileWindowFunctionB\x11\n\x0fwindow_functionB\x0f\n\r_series_title"\x89\x05\n&GetFeatureValuesTimeSeriesChartRequest\x12\x19\n\x05title\x18\x01 \x01(\tH\x00R\x05title\x88\x01\x01\x12;\n\x06series\x18\x02 \x03(\x0b\x32#.chalk.engine.v2.FeatureValueSeriesR\x06series\x12>\n\rwindow_period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cwindowPeriod\x12V\n\x19start_timestamp_inclusive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x17startTimestampInclusive\x12W\n\x17\x65nd_timestamp_exclusive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\x15\x65ndTimestampExclusive\x88\x01\x01\x12M\n\x0btime_series\x18\x06 \x01(\x0e\x32\'.chalk.engine.v2.FeatureValueTimeSeriesH\x02R\ntimeSeries\x88\x01\x01\x12?\n\x08group_by\x18\x07 \x03(\x0e\x32$.chalk.engine.v2.FeatureValueGroupByR\x07groupBy\x12\x36\n\x15group_by_series_limit\x18\x08 \x01(\x05H\x03R\x12groupBySeriesLimit\x88\x01\x01\x42\x08\n\x06_titleB\x1a\n\x18_end_timestamp_exclusiveB\x0e\n\x0c_time_seriesB\x18\n\x16_group_by_series_limit"e\n\'GetFeatureValuesTimeSeriesChartResponse\x12:\n\x05\x63hart\x18\x01 \x01(\x0b\x32$.chalk.chart.v1.DenseTimeSeriesChartR\x05\x63hart*\xc6\x03\n\x1e\x46\x65\x61tureValueBaseWindowFunction\x12\x32\n.FEATURE_VALUE_BASE_WINDOW_FUNCTION_UNSPECIFIED\x10\x00\x12\x34\n0FEATURE_VALUE_BASE_WINDOW_FUNCTION_UNIQUE_VALUES\x10\x01\x12\x39\n5FEATURE_VALUE_BASE_WINDOW_FUNCTION_TOTAL_OBSERVATIONS\x10\x02\x12\x36\n2FEATURE_VALUE_BASE_WINDOW_FUNCTION_NULL_PERCENTAGE\x10\x03\x12\x30\n,FEATURE_VALUE_BASE_WINDOW_FUNCTION_MAX_VALUE\x10\x04\x12\x30\n,FEATURE_VALUE_BASE_WINDOW_FUNCTION_MIN_VALUE\x10\x05\x12.\n*FEATURE_VALUE_BASE_WINDOW_FUNCTION_AVERAGE\x10\x06\x12\x33\n/FEATURE_VALUE_BASE_WINDOW_FUNCTION_UNIQUE_PKEYS\x10\x07*\xe2\x02\n\x13\x46\x65\x61tureValueGroupBy\x12&\n"FEATURE_VALUE_GROUP_BY_UNSPECIFIED\x10\x00\x12,\n(FEATURE_VALUE_GROUP_BY_CATEGORICAL_VALUE\x10\x01\x12&\n"FEATURE_VALUE_GROUP_BY_PRIMARY_KEY\x10\x02\x12(\n$FEATURE_VALUE_GROUP_BY_DEPLOYMENT_ID\x10\x03\x12#\n\x1f\x46\x45\x41TURE_VALUE_GROUP_BY_RESOLVER\x10\x04\x12)\n%FEATURE_VALUE_GROUP_BY_OPERATION_KIND\x10\x05\x12\'\n#FEATURE_VALUE_GROUP_BY_OPERATION_ID\x10\x06\x12*\n&FEATURE_VALUE_GROUP_BY_FEATURE_VERSION\x10\x07*\x99\x01\n\x16\x46\x65\x61tureValueTimeSeries\x12)\n%FEATURE_VALUE_TIME_SERIES_UNSPECIFIED\x10\x00\x12)\n%FEATURE_VALUE_TIME_SERIES_INSERTED_AT\x10\x01\x12)\n%FEATURE_VALUE_TIME_SERIES_OBSERVED_AT\x10\x02\x42\x8c\x01\n\x13\x63om.chalk.engine.v2B\x17\x46\x65\x61tureValuesChartProtoP\x01\xa2\x02\x03\x43\x45X\xaa\x02\x0f\x43halk.Engine.V2\xca\x02\x0f\x43halk\\Engine\\V2\xe2\x02\x1b\x43halk\\Engine\\V2\\GPBMetadata\xea\x02\x11\x43halk::Engine::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.engine.v2.feature_values_chart_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\023com.chalk.engine.v2B\027FeatureValuesChartProtoP\001\242\002\003CEX\252\002\017Chalk.Engine.V2\312\002\017Chalk\\Engine\\V2\342\002\033Chalk\\Engine\\V2\\GPBMetadata\352\002\021Chalk::Engine::V2"
    _globals["_FEATUREVALUEBASEWINDOWFUNCTION"]._serialized_start = 1351
    _globals["_FEATUREVALUEBASEWINDOWFUNCTION"]._serialized_end = 1805
    _globals["_FEATUREVALUEGROUPBY"]._serialized_start = 1808
    _globals["_FEATUREVALUEGROUPBY"]._serialized_end = 2162
    _globals["_FEATUREVALUETIMESERIES"]._serialized_start = 2165
    _globals["_FEATUREVALUETIMESERIES"]._serialized_end = 2318
    _globals["_FEATUREVALUEPERCENTILEWINDOWFUNCTION"]._serialized_start = 171
    _globals["_FEATUREVALUEPERCENTILEWINDOWFUNCTION"]._serialized_end = 241
    _globals["_FEATUREVALUESERIES"]._serialized_start = 244
    _globals["_FEATUREVALUESERIES"]._serialized_end = 593
    _globals["_GETFEATUREVALUESTIMESERIESCHARTREQUEST"]._serialized_start = 596
    _globals["_GETFEATUREVALUESTIMESERIESCHARTREQUEST"]._serialized_end = 1245
    _globals["_GETFEATUREVALUESTIMESERIESCHARTRESPONSE"]._serialized_start = 1247
    _globals["_GETFEATUREVALUESTIMESERIESCHARTRESPONSE"]._serialized_end = 1348
# @@protoc_insertion_point(module_scope)
